searchData={"items":[{"type":"module","title":"Cldr.Number","doc":"Formats numbers and currencies based upon CLDR's decimal formats specification.\n\nThe format specification is documentated in [Unicode TR35](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Formats).\nThere are several classes of formatting including non-scientific, scientific,\nrules based (for spelling and ordinal formats), compact formats that display `1k`\nrather than `1,000` and so on.  See `Cldr.Number.to_string/2` for specific formatting\noptions.","ref":"Cldr.Number.html"},{"type":"module","title":"Non-Scientific Notation Formatting - Cldr.Number","doc":"The following description applies to formats that do not use scientific\nnotation or significant digits:\n\n* If the number of actual integer digits exceeds the maximum integer digits,\n  then only the least significant digits are shown. For example, 1997 is\n  formatted as \"97\" if the maximum integer digits is set to 2.\n\n* If the number of actual integer digits is less than the minimum integer\n  digits, then leading zeros are added. For example, 1997 is formatted as\n  \"01997\" if the minimum integer digits is set to 5.\n\n* If the number of actual fraction digits exceeds the maximum fraction\n  digits, then half-even rounding it performed to the maximum fraction\n  digits. For example, 0.125 is formatted as \"0.12\" if the maximum fraction\n  digits is 2. This behavior can be changed by specifying a rounding\n  increment and a rounding mode.\n\n* If the number of actual fraction digits is less than the minimum fraction\n  digits, then trailing zeros are added. For example, 0.125 is formatted as\n  \"0.1250\" if the minimum fraction digits is set to 4.\n\n* Trailing fractional zeros are not displayed if they occur j positions after\n  the decimal, where j is less than the maximum fraction digits. For example,\n  0.10004 is formatted as \"0.1\" if the maximum fraction digits is four or\n  less.","ref":"Cldr.Number.html#module-non-scientific-notation-formatting"},{"type":"module","title":"Scientific Notation Formatting - Cldr.Number","doc":"Numbers in scientific notation are expressed as the product of a mantissa and\na power of ten, for example, 1234 can be expressed as 1.234 x 10^3. The\nmantissa is typically in the half-open interval [1.0, 10.0) or sometimes\n[0.0, 1.0), but it need not be. In a pattern, the exponent character\nimmediately followed by one or more digit characters indicates scientific\nnotation. Example: \"0.###E0\" formats the number 1234 as \"1.234E3\".\n\n* The number of digit characters after the exponent character gives the\n  minimum exponent digit count. There is no maximum. Negative exponents are\n  formatted using the localized minus sign, not the prefix and suffix from\n  the pattern. This allows patterns such as \"0.###E0 m/s\". To prefix positive\n  exponents with a localized plus sign, specify '+' between the exponent and\n  the digits: \"0.###E+0\" will produce formats \"1E+1\", \"1E+0\", \"1E-1\", and so\n  on. (In localized patterns, use the localized plus sign rather than '+'.)\n\n* The minimum number of integer digits is achieved by adjusting the exponent.\n  Example: 0.00123 formatted with \"00.###E0\" yields \"12.3E-4\". This only\n  happens if there is no maximum number of integer digits. If there is a\n  maximum, then the minimum number of integer digits is fixed at one.\n\n* The maximum number of integer digits, if present, specifies the exponent\n  grouping. The most common use of this is to generate engineering notation,\n  in which the exponent is a multiple of three, for example, \"##0.###E0\". The\n  number 12345 is formatted using \"##0.####E0\" as \"12.345E3\".\n\n* When using scientific notation, the formatter controls the digit counts\n  using significant digits logic. The maximum number of significant digits\n  limits the total number of integer and fraction digits that will be shown\n  in the mantissa; it does not affect parsing. For example, 12345 formatted\n  with \"##0.##E0\" is \"12.3E3\". Exponential patterns may not contain grouping\n  separators.","ref":"Cldr.Number.html#module-scientific-notation-formatting"},{"type":"module","title":"Significant Digits - Cldr.Number","doc":"There are two ways of controlling how many digits are shows: (a)\nsignificant digits counts, or (b) integer and fraction digit counts. Integer\nand fraction digit counts are described above. When a formatter is using\nsignificant digits counts, it uses however many integer and fraction digits\nare required to display the specified number of significant digits. It may\nignore min/max integer/fraction digits, or it may use them to the extent\npossible.","ref":"Cldr.Number.html#module-significant-digits"},{"type":"function","title":"Cldr.Number.decimal_format_metadata/2","doc":"Returns the metadata representing the given\nformat.","ref":"Cldr.Number.html#decimal_format_metadata/2"},{"type":"function","title":"Cldr.Number.precision/1","doc":"Return the precision (number of digits) of a number\n\nThis function delegates to `Cldr.Digits.number_of_digits/1`","ref":"Cldr.Number.html#precision/1"},{"type":"function","title":"Example - Cldr.Number.precision/1","doc":"iex> Cldr.Number.precision 1.234\n    4","ref":"Cldr.Number.html#precision/1-example"},{"type":"function","title":"Cldr.Number.to_approx_string/3","doc":"Formats a number and applies the `:approximately` format for\na locale and number system.","ref":"Cldr.Number.html#to_approx_string/3"},{"type":"function","title":"Arguments - Cldr.Number.to_approx_string/3","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","ref":"Cldr.Number.html#to_approx_string/3-arguments"},{"type":"function","title":"Example - Cldr.Number.to_approx_string/3","doc":"iex> Cldr.Number.to_approx_string 1234, TestBackend.Cldr\n    {:ok, \"~1,234\"}","ref":"Cldr.Number.html#to_approx_string/3-example"},{"type":"function","title":"Cldr.Number.to_at_least_string/3","doc":"Formats a number and applies the `:at_least` format for\na locale and number system.","ref":"Cldr.Number.html#to_at_least_string/3"},{"type":"function","title":"Arguments - Cldr.Number.to_at_least_string/3","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","ref":"Cldr.Number.html#to_at_least_string/3-arguments"},{"type":"function","title":"Example - Cldr.Number.to_at_least_string/3","doc":"iex> Cldr.Number.to_at_least_string 1234, TestBackend.Cldr\n    {:ok, \"1,234+\"}","ref":"Cldr.Number.html#to_at_least_string/3-example"},{"type":"function","title":"Cldr.Number.to_at_most_string/3","doc":"Formats a number and applies the `:at_most` format for\na locale and number system.","ref":"Cldr.Number.html#to_at_most_string/3"},{"type":"function","title":"Arguments - Cldr.Number.to_at_most_string/3","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","ref":"Cldr.Number.html#to_at_most_string/3-arguments"},{"type":"function","title":"Example - Cldr.Number.to_at_most_string/3","doc":"iex> Cldr.Number.to_at_most_string 1234, TestBackend.Cldr\n    {:ok, \"≤1,234\"}","ref":"Cldr.Number.html#to_at_most_string/3-example"},{"type":"function","title":"Cldr.Number.to_number_system/3","doc":"Converts a number from the latin digits `0..9` into\nanother number system.  Returns `{:ok, string}` or\n`{:error, reason}`.\n\n* `number` is an integer, float.  Decimal is supported only for\n  `:numeric` number systems, not `:algorithmic`.  See `Cldr.Number.System.to_system/3`\n  for further information.\n\n* `system` is any number system returned by `Cldr.known_number_systems/0`","ref":"Cldr.Number.html#to_number_system/3"},{"type":"function","title":"Examples - Cldr.Number.to_number_system/3","doc":"iex> Cldr.Number.to_number_system 123, :hant, TestBackend.Cldr\n    {:ok, \"一百二十三\"}\n\n    iex> Cldr.Number.to_number_system 123, :hebr, TestBackend.Cldr\n    {:ok, \"קכ״ג\"}","ref":"Cldr.Number.html#to_number_system/3-examples"},{"type":"function","title":"Cldr.Number.to_number_system!/3","doc":"Converts a number from the latin digits `0..9` into\nanother number system. Returns the converted number\nor raises an exception on error.\n\n* `number` is an integer, float.  Decimal is supported only for\n  `:numeric` number systems, not `:algorithmic`.  See `Cldr.Number.System.to_system/3`\n  for further information.\n\n* `system` is any number system returned by `Cldr.Number.System.known_number_systems/0`","ref":"Cldr.Number.html#to_number_system!/3"},{"type":"function","title":"Example - Cldr.Number.to_number_system!/3","doc":"iex> Cldr.Number.to_number_system! 123, :hant, TestBackend.Cldr\n    \"一百二十三\"","ref":"Cldr.Number.html#to_number_system!/3-example"},{"type":"function","title":"Cldr.Number.to_range_string/3","doc":"Formats the first and last numbers of a range and applies\nthe `:range` format for a locale and number system.","ref":"Cldr.Number.html#to_range_string/3"},{"type":"function","title":"Arguments - Cldr.Number.to_range_string/3","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","ref":"Cldr.Number.html#to_range_string/3-arguments"},{"type":"function","title":"Example - Cldr.Number.to_range_string/3","doc":"iex> Cldr.Number.to_range_string 1234..5678, TestBackend.Cldr\n    {:ok, \"1,234–5,678\"}","ref":"Cldr.Number.html#to_range_string/3-example"},{"type":"function","title":"Cldr.Number.to_string/3","doc":"Returns a number formatted into a string according to a format pattern and options.","ref":"Cldr.Number.html#to_string/3"},{"type":"function","title":"Arguments - Cldr.Number.to_string/3","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`\n\n* `options` is a keyword list defining how the number is to be formatted. The\n  valid options are:","ref":"Cldr.Number.html#to_string/3-arguments"},{"type":"function","title":"Options - Cldr.Number.to_string/3","doc":"* `format`: the format style or a format string defining how the number is\n  formatted. See `Cldr.Number.Format` for how format strings can be constructed.\n  See `Cldr.Number.Format.format_styles_for/3` to return available format styles\n  for a locale. The default `format` is `:standard`.\n\n* If `:format` is set to `:long` or `:short` then the formatting depends on\n  whether `:currency` is specified. If not specified then the number is\n  formatted as `:decimal_long` or `:decimal_short`. If `:currency` is\n  specified the number is formatted as `:currency_long` or\n  `:currency_short` and `:fractional_digits` is set to 0 as a default.\n\n* If `:format` is set to `:currency_long_with_symbol` then a format composed\n  of `:currency_long` with the locale's currency format is used.\n\n* `:format` may also be a format defined by CLDR's Rules Based Number\n  Formats (RBNF).  Further information is found in the module `Cldr.Rbnf`.\n  The most commonly used formats in this category are to spell out the\n  number in a the locales language.  The applicable formats are `:spellout`,\n  `:spellout_year`, `:ordinal`.  A number can also be formatted as roman\n  numbers by using the format `:roman` or `:roman_lower`.\n\n* `currency`: is the currency for which the number is formatted. If `currency`\n  is set and no `:format` is set, `:format` will be set to `:currency` as well.\n  Currency may be any [ISO 4217 currency code](https://en.wikipedia.org/wiki/ISO_4217)\n  returned by `Cldr.Currency.known_currencies/0` or a\n  [ISO 24165](https://www.iso.org/standard/80601.html) digital token\n  identifier (crypto currency).\n\n* `currency_symbol`: Allows overriding a currency symbol. The alternatives\n  are:\n  * `:iso` the ISO currency code will be used instead of the default\n    currency symbol.\n  * `:narrow` uses the narrow symbol defined for the locale. The same\n    narrow symbol can be defined for more than one currency and therefore this\n    should be used with care. If no narrow symbol is defined, the standard\n    symbol is used.\n  * `:symbol` uses the standard symbol defined in CLDR. A symbol is unique\n    for each currency and can be safely used.\n  * `:standard` (the default and recommended) uses the CLDR-defined symbol\n    based upon the currency format for the locale.\n  * \"string\" uses `string` as the currency symbol\n\n* `:cash`: a boolean which indicates whether a number being formatted as a\n  `:currency` is to be considered a cash value or not. Currencies can be\n  rounded differently depending on whether `:cash` is `true` or `false`.\n  *This option is deprecated in favour of `currency_digits: :cash`. Ignored\n  if the currency is a digital token.\n\n* `:currency_digits` indicates which of the rounding and digits should be\n  used. The options are `:accounting` which is the default, `:cash` or\n  `:iso`. Ignored if the currency is a digital token.\n\n* `:rounding_mode`: determines how a number is rounded to meet the precision\n  of the format requested. The available rounding modes are `:down`,\n  :half_up, :half_even, :ceiling, :floor, :half_down, :up. The default is\n  `:half_even`.\n\n* `:number_system`: determines which of the number systems for a locale\n  should be used to define the separators and digits for the formatted\n  number. If `number_system` is an `atom` then `number_system` is\n  interpreted as a number system. See\n  `Cldr.Number.System.number_systems_for/2`. If the `:number_system` is\n  `binary` then it is interpreted as a number system name. See\n  `Cldr.Number.System.number_system_names_for/2`. The default is `:default`.\n\n* `:locale`: determines the locale in which the number is formatted. See\n  `Cldr.known_locale_names/0`. The default is`Cldr.get_locale/0` which is the\n  locale currently in affect for this `Process` and which is set by\n  `Cldr.put_locale/1`.\n\n* If `:fractional_digits` is set to a positive integer value then the number\n  will be rounded to that number of digits and displayed accordingly - overriding\n  settings that would be applied by default.  For example, currencies have\n  fractional digits defined reflecting each currencies minor unit.  Setting\n  `:fractional_digits` will override that setting.\n\n* If `:maximum_integer_digits` is set to a positive integer value then the\n  number is left truncated before formatting. For example if the number `1234`\n  is formatted with the option `maximum_integer_digits: 2`, the number is\n  truncated to `34` and formatted.\n\n* If `:round_nearest` is set to a positive integer value then the number\n  will be rounded to nearest increment of that value - overriding\n  settings that would be applied by default.\n\n* `:minimum_grouping_digits` overrides the CLDR definition of minimum grouping\n  digits. For example in the locale `es` the number `1345` is formatted by default\n  as `1345` because the locale defines the `minimium_grouping_digits` as `2`. If\n  `minimum_grouping_digits: 1` is set as an option the number is formatted as\n  `1.345`. The `:minimum_grouping_digits` is added to the grouping defined by\n  the number format.  If the sum of these two digits is greater than the number\n  of digits in the integer (or fractional) part of the number then no grouping\n  is performed.\n\n* `:wrapper` is a 2-arity function that will be called for each number component\n  with parameters `string` and `tag` where `tag` is one of `:number`,\n  `:currency_symbol`, `:currency_space`, `:literal`, `:quote`, `:percent`,\n  `:permille`, `:minus` or `:plus`. The function must return either a string\n  or a Phoenix safe string such as that returned by `Phoenix.HTML.Tag.content_tag/3`.\n  The function can be used to wrap format elements in HTML or other tags.","ref":"Cldr.Number.html#to_string/3-options"},{"type":"function","title":"Locale extensions affecting formatting - Cldr.Number.to_string/3","doc":"A locale identifier can specify options that affect number formatting.\nThese options are:\n\n* `nu`: defines the number system to be used if none is specified by the `:number_system`\n  option to `to_string/2`\n\nThis key is part of the [u extension](https://unicode.org/reports/tr35/#u_Extension) and\nthat document should be consulted for details on how to construct a locale identifier with these\nextensions.","ref":"Cldr.Number.html#to_string/3-locale-extensions-affecting-formatting"},{"type":"function","title":"Wrapping format elements - Cldr.Number.to_string/3","doc":"Wrapping elements is particularly useful when formatting a number with a\ncurrency symbol and the requirement is to have different HTML formatting\napplied to the symbol than the number.  For example:\n\n    iex> Cldr.Number.to_string(100, format: :currency, currency: :USD, wrapper: fn\n    ...>   string, :currency_symbol -> \" \" <> string <> \" \"\n    ...>   string, :number -> \" \" <> string <> \" \"\n    ...>   string, :currency_space -> \" \" <> string <> \" \"\n    ...>   string, _other -> string\n    ...> end)\n    {:ok, \" $  100.00 \"}\n\nIt is also possible and recommended to use the `Phoenix.HTML.Tag.content_tag/3`\nfunction if wrapping HTML tags since these will ensure HTML entities are\ncorrectly encoded.  For example:\n\n    iex> Cldr.Number.to_string(100, format: :currency, currency: :USD, wrapper: fn\n    ...>   string, :currency_symbol -> Phoenix.HTML.Tag.content_tag(:span, string, class: \"symbol\")\n    ...>   string, :number -> Phoenix.HTML.Tag.content_tag(:span, string, class: \"number\")\n    ...>   string, :currency_space -> Phoenix.HTML.Tag.content_tag(:span, string)\n    ...>   string, _other -> string\n    ...> end)\n    {:ok, \" $  100.00 \"}\n\nWhen formatting a number the format is parsed into format elements that might include\na currency symbol, a literal string, inserted text between a currency symbol and the\ncurrency amount, a percent sign, the number itself and several other elements.  In\nsome cases it is helpful to be apply specific formatting to each element.\nThis can be achieved by specifying a `:wrapper` option. This option takes a 2-arity\nfunction as an argument. For each element of the format the wrapper function is called\nwith two parameters:  the format element as a string and an atom representing the\nelement type. The wrapper function is required to return a string that is then\ninserted in the final formatted number.","ref":"Cldr.Number.html#to_string/3-wrapping-format-elements"},{"type":"function","title":"Returns - Cldr.Number.to_string/3","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Number.html#to_string/3-returns"},{"type":"function","title":"Examples - Cldr.Number.to_string/3","doc":"iex> Cldr.Number.to_string 12345, TestBackend.Cldr\n    {:ok, \"12,345\"}\n\n    iex> Cldr.Number.to_string 12345, TestBackend.Cldr, locale: \"fr\"\n    {:ok, \"12 345\"}\n\n    iex> Cldr.Number.to_string 1345.32, TestBackend.Cldr, currency: :EUR, locale: \"es\", minimum_grouping_digits: 1\n    {:ok, \"1.345,32 €\"}\n\n    iex> Cldr.Number.to_string 1345.32, TestBackend.Cldr, currency: :EUR, locale: \"es\"\n    {:ok, \"1345,32 €\"}\n\n    iex> Cldr.Number.to_string 12345, TestBackend.Cldr, locale: \"fr\", currency: \"USD\"\n    {:ok, \"12 345,00 $US\"}\n\n    iex> Cldr.Number.to_string 12345, TestBackend.Cldr, format: \"#E0\"\n    {:ok, \"1.2345E4\"}\n\n    iex> Cldr.Number.to_string 12345, TestBackend.Cldr, format: :accounting, currency: \"THB\"\n    {:ok, \"THB 12,345.00\"}\n\n    iex> Cldr.Number.to_string -12345, TestBackend.Cldr, format: :accounting, currency: \"THB\"\n    {:ok, \"(THB 12,345.00)\"}\n\n    iex> Cldr.Number.to_string 12345, TestBackend.Cldr, format: :accounting, currency: \"THB\",\n    ...> locale: \"th\"\n    {:ok, \"฿12,345.00\"}\n\n    iex> Cldr.Number.to_string 12345, TestBackend.Cldr, format: :accounting, currency: \"THB\",\n    ...> locale: \"th\", number_system: :native\n    {:ok, \"฿๑๒,๓๔๕.๐๐\"}\n\n    iex> Cldr.Number.to_string 1244.30, TestBackend.Cldr, format: :long\n    {:ok, \"1 thousand\"}\n\n    iex> Cldr.Number.to_string 1244.30, TestBackend.Cldr, format: :long, currency: \"USD\"\n    {:ok, \"1,244 US dollars\"}\n\n    iex> Cldr.Number.to_string 1244.30, TestBackend.Cldr, format: :short\n    {:ok, \"1K\"}\n\n    iex> Cldr.Number.to_string 1244.30, TestBackend.Cldr, format: :short, currency: \"EUR\"\n    {:ok, \"€1K\"}\n\n    iex> Cldr.Number.to_string 1234, TestBackend.Cldr, format: :spellout\n    {:ok, \"one thousand two hundred thirty-four\"}\n\n    iex> Cldr.Number.to_string 1234, TestBackend.Cldr, format: :spellout_verbose\n    {:ok, \"one thousand two hundred and thirty-four\"}\n\n    iex> Cldr.Number.to_string 1989, TestBackend.Cldr, format: :spellout_year\n    {:ok, \"nineteen eighty-nine\"}\n\n    iex> Cldr.Number.to_string 123, TestBackend.Cldr, format: :ordinal\n    {:ok, \"123rd\"}\n\n    iex> Cldr.Number.to_string 123, TestBackend.Cldr, format: :roman\n    {:ok, \"CXXIII\"}\n\n    iex> Cldr.Number.to_string 123, TestBackend.Cldr, locale: \"th-u-nu-thai\"\n    {:ok, \"๑๒๓\"}","ref":"Cldr.Number.html#to_string/3-examples"},{"type":"function","title":"Errors - Cldr.Number.to_string/3","doc":"An error tuple `{:error, {exception, reason}}` will be returned if an error is detected.\nThe two most likely causes of an error return are:\n\n  * A format cannot be compiled. In this case the error tuple will look like:\n\n```\n    iex> Cldr.Number.to_string(12345, TestBackend.Cldr, format: \"0#\")\n    {:error, {Cldr.FormatCompileError,\n      \"Decimal format compiler: syntax error before: \\\"#\\\"\"}}\n```\n\n  * The format style requested is not defined for the `locale` and\n    `number_system`. This happens typically when the number system is\n    `:algorithmic` rather than the more common `:numeric`. In this case the error\n    return looks like:\n\n```\n    iex> Cldr.Number.to_string(1234, TestBackend.Cldr, locale: \"he\", number_system: \"hebr\", format: :percent)\n    {:error, {Cldr.UnknownFormatError,\n    \"The locale :he with number system :hebr does not define a format :percent\"}}\n```","ref":"Cldr.Number.html#to_string/3-errors"},{"type":"function","title":"Cldr.Number.to_string!/3","doc":"Same as the execution of `to_string/2` but raises an exception if an error would be\nreturned.","ref":"Cldr.Number.html#to_string!/3"},{"type":"function","title":"Options - Cldr.Number.to_string!/3","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted. See\n  `Cldr.Number.to_string/2`","ref":"Cldr.Number.html#to_string!/3-options"},{"type":"function","title":"Returns - Cldr.Number.to_string!/3","doc":"* a formatted number as a string or\n\n* raises an exception","ref":"Cldr.Number.html#to_string!/3-returns"},{"type":"function","title":"Examples - Cldr.Number.to_string!/3","doc":"iex> Cldr.Number.to_string! 12345, TestBackend.Cldr\n    \"12,345\"\n\n    iex> Cldr.Number.to_string! 12345, TestBackend.Cldr, locale: \"fr\"\n    \"12 345\"","ref":"Cldr.Number.html#to_string!/3-examples"},{"type":"function","title":"Cldr.Number.validate_number_system/3","doc":"Return a valid number system from a provided locale and number\nsystem name or type.\n\nThe number system or number system type must be valid for the\ngiven locale.  If a number system type is provided, the\nunderlying number system is returned.","ref":"Cldr.Number.html#validate_number_system/3"},{"type":"function","title":"Arguments - Cldr.Number.validate_number_system/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.html#validate_number_system/3-arguments"},{"type":"function","title":"Examples - Cldr.Number.validate_number_system/3","doc":"iex> Cldr.Number.validate_number_system :en, :latn, TestBackend.Cldr\n    {:ok, :latn}\n\n    iex> Cldr.Number.validate_number_system :en, :default, TestBackend.Cldr\n    {:ok, :latn}\n\n    iex> Cldr.Number.validate_number_system :en, :unknown, TestBackend.Cldr\n    {:error,\n     {Cldr.UnknownNumberSystemError, \"The number system :unknown is unknown\"}}\n\n    iex> Cldr.Number.validate_number_system \"zz\", :default, TestBackend.Cldr\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zz\\\" is invalid\"}}","ref":"Cldr.Number.html#validate_number_system/3-examples"},{"type":"type","title":"Cldr.Number.format_type/0","doc":"","ref":"Cldr.Number.html#t:format_type/0"},{"type":"module","title":"Cldr.Number.Format","doc":"Functions to manage the collection of number patterns defined in Cldr.\n\nNumber patterns affect how numbers are interpreted in a localized context.\nHere are some examples, based on the French locale. The \".\" shows where the\ndecimal point should go. The \",\" shows where the thousands separator should\ngo. A \"0\" indicates zero-padding: if the number is too short, a zero (in the\nlocale's numeric set) will go there. A \"#\" indicates no padding: if the\nnumber is too short, nothing goes there. A \"¤\" shows where the currency sign\nwill go. The following illustrates the effects of different patterns for the\nFrench locale, with the number \"1234.567\". Notice how the pattern characters\n',' and '.' are replaced by the characters appropriate for the locale.","ref":"Cldr.Number.Format.html"},{"type":"module","title":"Number Pattern Examples - Cldr.Number.Format","doc":"| Pattern\t      | Currency\t      | Text        |\n| ------------- | :-------------: | ----------: |\n| #,##0.##\t    | n/a\t            | 1 234,57    |\n| #,##0.###\t    | n/a\t            | 1 234,567   |\n| ###0.#####\t  | n/a\t            | 1234,567    |\n| ###0.0000#\t  | n/a\t            | 1234,5670   |\n| 00000.0000\t  | n/a\t            | 01234,5670  |\n| #,##0.00 ¤\t  | EUR\t            | 1 234,57 €  |\n\nThe number of # placeholder characters before the decimal do not matter,\nsince no limit is placed on the maximum number of digits. There should,\nhowever, be at least one zero some place in the pattern. In currency formats,\nthe number of digits after the decimal also do not matter, since the\ninformation in the supplemental data (see Supplemental Currency Data) is used\nto override the number of decimal places — and the rounding — according to\nthe currency that is being formatted. That can be seen in the above chart,\nwith the difference between Yen and Euro formatting.\n\nDetails of the number formats are described in the\n[Unicode documentation](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Format_Patterns)","ref":"Cldr.Number.Format.html#module-number-pattern-examples"},{"type":"function","title":"Cldr.Number.Format.all_formats_for/2","doc":"Returns the decimal formats defined for a given locale.","ref":"Cldr.Number.Format.html#all_formats_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.all_formats_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#all_formats_for/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.all_formats_for/2","doc":"* `{:ok, map_of_formats_by_number_system}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.Format.html#all_formats_for/2-returns"},{"type":"function","title":"Examples - Cldr.Number.Format.all_formats_for/2","doc":"Cldr.Number.Format.all_formats_for(\"en\", MyApp.Cldr)\n    #=> {:ok, %{latn: %Cldr.Number.Format{\n      accounting: \"¤#,##0.00;(¤#,##0.00)\",\n      currency: \"¤#,##0.00\",\n      percent: \"#,##0%\",\n      scientific: \"#E0\",\n      standard: \"#,##0.###\",\n      currency_short: [{\"1000\", [one: \"¤0K\", other: \"¤0K\"]},\n       {\"10000\", [one: \"¤00K\", other: \"¤00K\"]},\n       {\"100000\", [one: \"¤000K\", other: \"¤000K\"]},\n       {\"1000000\", [one: \"¤0M\", other: \"¤0M\"]},\n       {\"10000000\", [one: \"¤00M\", other: \"¤00M\"]},\n       {\"100000000\", [one: \"¤000M\", other: \"¤000M\"]},\n       {\"1000000000\", [one: \"¤0B\", other: \"¤0B\"]},\n       {\"10000000000\", [one: \"¤00B\", other: \"¤00B\"]},\n       {\"100000000000\", [one: \"¤000B\", other: \"¤000B\"]},\n       {\"1000000000000\", [one: \"¤0T\", other: \"¤0T\"]},\n       {\"10000000000000\", [one: \"¤00T\", other: \"¤00T\"]},\n       {\"100000000000000\", [one: \"¤000T\", other: \"¤000T\"]}],\n       ....\n      }}","ref":"Cldr.Number.Format.html#all_formats_for/2-examples"},{"type":"function","title":"Cldr.Number.Format.all_formats_for!/2","doc":"Returns the decimal formats defined for a given locale.","ref":"Cldr.Number.Format.html#all_formats_for!/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.all_formats_for!/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#all_formats_for!/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.all_formats_for!/2","doc":"* a list of decimal formats or\n\n* raises an exception\n\nSee `Cldr.Number.Format.all_formats_for/2` for further information.","ref":"Cldr.Number.Format.html#all_formats_for!/2-returns"},{"type":"function","title":"Cldr.Number.Format.currency_spacing/3","doc":"Returns the currency space for a given locale and\nnumber system.","ref":"Cldr.Number.Format.html#currency_spacing/3"},{"type":"function","title":"Arguments - Cldr.Number.Format.currency_spacing/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `number_system` is any valid number system or number system type returned\n  by `Cldr.Number.System.number_systems_for/2`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#currency_spacing/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.currency_spacing/3","doc":"* A map defining how spacing between a currency symbol and\n  its number format should be applied.","ref":"Cldr.Number.Format.html#currency_spacing/3-returns"},{"type":"function","title":"Example - Cldr.Number.Format.currency_spacing/3","doc":"iex> Cldr.Number.Format.currency_spacing(:en, :latn, MyApp.Cldr)\n    %{\n      before_currency: %{\n        insert_between: \" \",\n        surrounding_match: \"[[:digit:]]\",\n        currency_match: \"[[:^S:]&[:^Z:]]\"\n      },\n      after_currency: %{\n        insert_between: \" \",\n        surrounding_match: \"[[:digit:]]\",\n        currency_match: \"[[:^S:]&[:^Z:]]\"\n      }\n    }","ref":"Cldr.Number.Format.html#currency_spacing/3-example"},{"type":"function","title":"Cldr.Number.Format.decimal_format_list/1","doc":"Returns the list of decimal formats in the configured locales including\nthe list of locales configured for precompilation in `config.exs`.\n\nThis function exists to allow the decimal formatter\nto precompile all the known formats at compile time.","ref":"Cldr.Number.Format.html#decimal_format_list/1"},{"type":"function","title":"Arguments - Cldr.Number.Format.decimal_format_list/1","doc":"* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#decimal_format_list/1-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.decimal_format_list/1","doc":"* `[decimal_formats_as_strings]`.\n\n##@ Example\n\n    => Cldr.Number.Format.decimal_format_list(MyApp.Cldr)\n    [\"#\", \"#,##,##0%\", \"#,##,##0.###\", \"#,##,##0.00¤\", \"#,##,##0.00¤;(#,##,##0.00¤)\",\n    \"#,##,##0 %\", \"#,##0%\", \"#,##0.###\", \"#,##0.00 ¤\",\n    \"#,##0.00 ¤;(#,##0.00 ¤)\", \"#,##0.00¤\", \"#,##0.00¤;(#,##0.00¤)\",\n    \"#,##0 %\", \"#0%\", \"#0.######\", \"#0.00 ¤\", \"#E0\", \"%#,##0\", \"% #,##0\",\n    \"0\", \"0.000000E+000\", \"0000 M ¤\", \"0000¤\", \"000G ¤\", \"000K ¤\", \"000M ¤\",\n    \"000T ¤\", \"000mM ¤\", \"000m ¤\", \"000 Bio'.' ¤\", \"000 Bln ¤\", \"000 Bn ¤\",\n    \"000 B ¤\", \"000 E ¤\", \"000 K ¤\", \"000 MRD ¤\", \"000 Md ¤\", \"000 Mio'.' ¤\",\n    \"000 Mio ¤\", \"000 Mld ¤\", \"000 Mln ¤\", \"000 Mn ¤\", \"000 Mrd'.' ¤\",\n    \"000 Mrd ¤\", \"000 Mr ¤\", \"000 M ¤\", \"000 NT ¤\", \"000 N ¤\", \"000 Tn ¤\",\n    \"000 Tr ¤\", ...]","ref":"Cldr.Number.Format.html#decimal_format_list/1-returns"},{"type":"function","title":"Cldr.Number.Format.decimal_format_list_for/2","doc":"Returns the list of decimal formats for a configured locale.","ref":"Cldr.Number.Format.html#decimal_format_list_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.decimal_format_list_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.\n\nThis function exists to allow the decimal formatter to precompile all\nthe known formats at compile time. Its use is not otherwise recommended.","ref":"Cldr.Number.Format.html#decimal_format_list_for/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.decimal_format_list_for/2","doc":"* `{:ok, list_of_decimal_formats_as_strings}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.Format.html#decimal_format_list_for/2-returns"},{"type":"function","title":"Example - Cldr.Number.Format.decimal_format_list_for/2","doc":"iex> Cldr.Number.Format.decimal_format_list_for(\"en\", MyApp.Cldr)\n    {:ok, [\"#,##0%\", \"#,##0.###\", \"#,##0.00\", \"#,##0.00;(#,##0.00)\",\"#E0\",\n     \"0 billion\", \"0 million\", \"0 thousand\",\n     \"0 trillion\", \"00 billion\", \"00 million\", \"00 thousand\", \"00 trillion\",\n     \"000 billion\", \"000 million\", \"000 thousand\", \"000 trillion\", \"000B\", \"000K\",\n     \"000M\", \"000T\", \"00B\", \"00K\", \"00M\", \"00T\", \"0B\", \"0K\", \"0M\", \"0T\",\n     \"¤#,##0.00\", \"¤#,##0.00;(¤#,##0.00)\", \"¤000B\", \"¤000K\", \"¤000M\",\n     \"¤000T\", \"¤00B\", \"¤00K\", \"¤00M\", \"¤00T\", \"¤0B\", \"¤0K\", \"¤0M\", \"¤0T\",\n     \"¤ #,##0.00\", \"¤ #,##0.00;(¤ #,##0.00)\", \"¤ 000B\", \"¤ 000K\", \"¤ 000M\",\n     \"¤ 000T\", \"¤ 00B\", \"¤ 00K\", \"¤ 00M\", \"¤ 00T\", \"¤ 0B\", \"¤ 0K\", \"¤ 0M\", \"¤ 0T\"]}","ref":"Cldr.Number.Format.html#decimal_format_list_for/2-example"},{"type":"function","title":"Cldr.Number.Format.decimal_format_styles_for/3","doc":"Returns the decimal format styles that are supported by\n`Cldr.Number.Formatter.Decimal`.","ref":"Cldr.Number.Format.html#decimal_format_styles_for/3"},{"type":"function","title":"Arguments - Cldr.Number.Format.decimal_format_styles_for/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`\n\n* `number_system` is any valid number system or number system type returned\n  by `Cldr.Number.System.number_systems_for/2`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#decimal_format_styles_for/3-arguments"},{"type":"function","title":"Example - Cldr.Number.Format.decimal_format_styles_for/3","doc":"iex> {:ok, styles} = Cldr.Number.Format.decimal_format_styles_for(\"en\", :latn, MyApp.Cldr)\n    iex> Enum.sort(styles)\n    [\n      :accounting,\n      :accounting_alpha_next_to_number,\n      :accounting_no_symbol,\n      :currency,\n      :currency_alpha_next_to_number,\n      :currency_long,\n      :currency_no_symbol,\n      :percent,\n      :scientific,\n      :standard\n    ]","ref":"Cldr.Number.Format.html#decimal_format_styles_for/3-example"},{"type":"function","title":"Cldr.Number.Format.default_grouping_for/2","doc":"Returns the default grouping for a locale.","ref":"Cldr.Number.Format.html#default_grouping_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.default_grouping_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/0`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#default_grouping_for/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.default_grouping_for/2","doc":"* `{:ok, minumum_digits}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Number.Format.html#default_grouping_for/2-returns"},{"type":"function","title":"Examples - Cldr.Number.Format.default_grouping_for/2","doc":"iex> Cldr.Number.Format.default_grouping_for(\"en\", MyApp.Cldr)\n    {:ok, %{fraction: %{first: 0, rest: 0}, integer: %{first: 3, rest: 3}}}","ref":"Cldr.Number.Format.html#default_grouping_for/2-examples"},{"type":"function","title":"Cldr.Number.Format.default_grouping_for!/2","doc":"Returns the default grouping for a locale or raises if there is an error.","ref":"Cldr.Number.Format.html#default_grouping_for!/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.default_grouping_for!/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#default_grouping_for!/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.default_grouping_for!/2","doc":"* default grouping definition as a map.","ref":"Cldr.Number.Format.html#default_grouping_for!/2-returns"},{"type":"function","title":"Examples - Cldr.Number.Format.default_grouping_for!/2","doc":"iex> Cldr.Number.Format.default_grouping_for!(\"en\", MyApp.Cldr)\n    %{fraction: %{first: 0, rest: 0}, integer: %{first: 3, rest: 3}}\n\n    Cldr.Number.Format.default_grouping_for!(:invalid)\n    ** (Cldr.UnknownLocaleError) The locale :invalid is invalid","ref":"Cldr.Number.Format.html#default_grouping_for!/2-examples"},{"type":"function","title":"Cldr.Number.Format.format_styles_for/3","doc":"Returns the format styles available for a `locale`.","ref":"Cldr.Number.Format.html#format_styles_for/3"},{"type":"function","title":"Arguments - Cldr.Number.Format.format_styles_for/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `number_system` is any valid number system or number system type returned\n  by `Cldr.Number.System.number_systems_for/2`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.\n\nFormat styles standardise the access to a format defined for a common\nuse.  These types are `:standard`, `:currency`, `:accounting`, `:scientific`\nand :percent, :currency_short, :decimal_short, :decimal_long.\n\nThese types can be used when formatting a number for output.  For example\n`Cldr.Number.to_string(123.456, format: :percent)`.","ref":"Cldr.Number.Format.html#format_styles_for/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.format_styles_for/3","doc":"* `[format_styles]` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.Format.html#format_styles_for/3-returns"},{"type":"function","title":"Example - Cldr.Number.Format.format_styles_for/3","doc":"iex> {:ok, format_styles} = Cldr.Number.Format.format_styles_for(\"en\", :latn, MyApp.Cldr)\n    iex> Enum.sort(format_styles)\n    [\n      :accounting,\n      :accounting_alpha_next_to_number,\n      :accounting_no_symbol,\n      :currency,\n      :currency_alpha_next_to_number,\n      :currency_long,\n      :currency_no_symbol,\n      :currency_short,\n      :decimal_long,\n      :decimal_short,\n      :percent,\n      :scientific,\n      :standard\n    ]","ref":"Cldr.Number.Format.html#format_styles_for/3-example"},{"type":"function","title":"Cldr.Number.Format.format_system_names_for/2","doc":"Returns the names of the number systems for the `locale`.","ref":"Cldr.Number.Format.html#format_system_names_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.format_system_names_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#format_system_names_for/2-arguments"},{"type":"function","title":"Examples - Cldr.Number.Format.format_system_names_for/2","doc":"iex> Cldr.Number.Format.format_system_names_for(\"th\", MyApp.Cldr)\n    {:ok, [:latn, :thai]}\n\n    iex> Cldr.Number.Format.format_system_names_for(\"pl\", MyApp.Cldr)\n    {:ok, [:latn]}","ref":"Cldr.Number.Format.html#format_system_names_for/2-examples"},{"type":"function","title":"Cldr.Number.Format.format_system_types_for/2","doc":"Returns the number system types available for a `locale`","ref":"Cldr.Number.Format.html#format_system_types_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.format_system_types_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.\n\nA number system type is an identifier that categorises number systems\nthat comprise a site of digits or rules for transliterating or translating\ndigits and a number system name for determining plural rules and format\nmasks.\n\nIf that all sounds a bit complicated then the default `number system type`\ncalled `:default` is probably what you want nearly all the time.","ref":"Cldr.Number.Format.html#format_system_types_for/2-arguments"},{"type":"function","title":"Examples - Cldr.Number.Format.format_system_types_for/2","doc":"iex> Cldr.Number.Format.format_system_types_for(\"pl\", MyApp.Cldr)\n    {:ok, [:default, :native]}\n\n    iex> Cldr.Number.Format.format_system_types_for(\"ru\", MyApp.Cldr)\n    {:ok, [:default, :native]}\n\n    iex> Cldr.Number.Format.format_system_types_for(\"th\", MyApp.Cldr)\n    {:ok, [:default, :native]}","ref":"Cldr.Number.Format.html#format_system_types_for/2-examples"},{"type":"function","title":"Cldr.Number.Format.formats_for/3","doc":"Return the predfined formats for a given `locale` and `number_system`.","ref":"Cldr.Number.Format.html#formats_for/3"},{"type":"function","title":"Arguments - Cldr.Number.Format.formats_for/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `number_system` is any valid number system or number system type returned\n  by `Cldr.Number.System.number_systems_for/2` or `Cldr.Number.System.number_system_names_for/2`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#formats_for/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.formats_for/3","doc":"* `{:ok, Cldr.Number.Format struct}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.Format.html#formats_for/3-returns"},{"type":"function","title":"Example - Cldr.Number.Format.formats_for/3","doc":"Cldr.Number.Format.formats_for \"fr\", :native, MyApp.Cldr\n    #=> {:ok, %Cldr.Number.Format{\n      accounting: \"#,##0.00 ¤;(#,##0.00 ¤)\",\n      currency: \"#,##0.00 ¤\",\n      percent: \"#,##0 %\",\n      scientific: \"#E0\",\n      standard: \"#,##0.###\"\n      currency_short: [{\"1000\", [one: \"0 k ¤\", other: \"0 k ¤\"]},\n       {\"10000\", [one: \"00 k ¤\", other: \"00 k ¤\"]},\n       {\"100000\", [one: \"000 k ¤\", other: \"000 k ¤\"]},\n       {\"1000000\", [one: \"0 M ¤\", other: \"0 M ¤\"]},\n       {\"10000000\", [one: \"00 M ¤\", other: \"00 M ¤\"]},\n       {\"100000000\", [one: \"000 M ¤\", other: \"000 M ¤\"]},\n       {\"1000000000\", [one: \"0 Md ¤\", other: \"0 Md ¤\"]},\n       {\"10000000000\", [one: \"00 Md ¤\", other: \"00 Md ¤\"]},\n       {\"100000000000\", [one: \"000 Md ¤\", other: \"000 Md ¤\"]},\n       {\"1000000000000\", [one: \"0 Bn ¤\", other: \"0 Bn ¤\"]},\n       {\"10000000000000\", [one: \"00 Bn ¤\", other: \"00 Bn ¤\"]},\n       {\"100000000000000\", [one: \"000 Bn ¤\", other: \"000 Bn ¤\"]}],\n       ...\n      }}","ref":"Cldr.Number.Format.html#formats_for/3-example"},{"type":"function","title":"Cldr.Number.Format.formats_for!/3","doc":"Return the predfined formats for a given `locale` and `number_system` or raises\nif either the `locale` or `number_system` is invalid.","ref":"Cldr.Number.Format.html#formats_for!/3"},{"type":"function","title":"Arguments - Cldr.Number.Format.formats_for!/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `number_system` is any valid number system or number system type returned\n  by `Cldr.Number.System.number_systems_for/2`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#formats_for!/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.formats_for!/3","doc":"* `Cldr.Number.Format struct` or\n\n* raises an exception.","ref":"Cldr.Number.Format.html#formats_for!/3-returns"},{"type":"function","title":"Cldr.Number.Format.minimum_grouping_digits_for/2","doc":"Returns the minimum grouping digits for a locale.","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.minimum_grouping_digits_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/0`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.minimum_grouping_digits_for/2","doc":"* `{:ok, minumum_digits}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for/2-returns"},{"type":"function","title":"Examples - Cldr.Number.Format.minimum_grouping_digits_for/2","doc":"iex> Cldr.Number.Format.minimum_grouping_digits_for(\"en\", MyApp.Cldr)\n    {:ok, 1}","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for/2-examples"},{"type":"function","title":"Cldr.Number.Format.minimum_grouping_digits_for!/2","doc":"Returns the minimum grouping digits for a locale or raises if there is an error.","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for!/2"},{"type":"function","title":"Arguments - Cldr.Number.Format.minimum_grouping_digits_for!/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for!/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.Format.minimum_grouping_digits_for!/2","doc":"* the number of grouping digits as an integer","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for!/2-returns"},{"type":"function","title":"Examples - Cldr.Number.Format.minimum_grouping_digits_for!/2","doc":"iex> Cldr.Number.Format.minimum_grouping_digits_for!(\"en\", MyApp.Cldr)\n    1\n\n    Cldr.Number.Format.minimum_grouping_digits_for!(:invalid)\n    ** (Cldr.UnknownLocaleError) The locale :invalid is invalid","ref":"Cldr.Number.Format.html#minimum_grouping_digits_for!/2-examples"},{"type":"function","title":"Cldr.Number.Format.short_format_styles/0","doc":"","ref":"Cldr.Number.Format.html#short_format_styles/0"},{"type":"function","title":"Cldr.Number.Format.short_format_styles_for/3","doc":"Returns the short formats available for a locale.","ref":"Cldr.Number.Format.html#short_format_styles_for/3"},{"type":"function","title":"Arguments - Cldr.Number.Format.short_format_styles_for/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. The default\n  is `Cldr.get_locale/1`.\n\n* `number_system` is any valid number system or number system type returned\n  by `Cldr.Number.System.number_systems_for/2`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0` which\n  will raiee an exception if not default backend is configured.","ref":"Cldr.Number.Format.html#short_format_styles_for/3-arguments"},{"type":"function","title":"Example - Cldr.Number.Format.short_format_styles_for/3","doc":"iex> {:ok, short_format_styles} = Cldr.Number.Format.short_format_styles_for(\"he\", :latn, MyApp.Cldr)\n    iex> Enum.sort(short_format_styles)\n    [:currency_short, :decimal_long, :decimal_short]","ref":"Cldr.Number.Format.html#short_format_styles_for/3-example"},{"type":"type","title":"Cldr.Number.Format.format/0","doc":"","ref":"Cldr.Number.Format.html#t:format/0"},{"type":"module","title":"Cldr.Number.Format.Compiler","doc":"Compiles number patterns with a lexer/parser into patterns for fast runtime interpretation.\n\nNumber patterns affect how numbers are interpreted in a localized context.\nHere are some examples, based on the French locale. The \".\" shows where the\ndecimal point should go. The \",\" shows where the thousands separator should go.\nA \"0\" indicates zero-padding: if the number is too short, a zero (in the\nlocale's numeric set) will go there. A \"#\" indicates no padding: if the number\nis too short, nothing goes there. A \"¤\" shows where the currency sign will go.\nThe following illustrates the effects of different patterns for the French\nlocale, with the number \"1234.567\". Notice how the pattern characters ',' and\n'.' are replaced by the characters appropriate for the locale.","ref":"Cldr.Number.Format.Compiler.html"},{"type":"module","title":"Number Pattern Examples - Cldr.Number.Format.Compiler","doc":"Pattern\t   | Currency\t | Text\n---------- | --------- | ----------\n#,##0.##\t | n/a\t     | 1 234,57\n#,##0.###\t | n/a\t     | 1 234,567\n###0.##### | n/a\t     | 1234,567\n###0.0000# | n/a\t     | 1234,5670\n00000.0000 | n/a\t     | 01234,5670\n#,##0.00 ¤ | EUR\t     | 1 234,57 €\n\nThe number of # placeholder characters before the decimal do not matter,\nsince no limit is placed on the maximum number of digits. There should,\nhowever, be at least one zero someplace in the pattern. In currency formats,\nthe number of digits after the decimal also do not matter, since the\ninformation in the supplemental data (see Supplemental Currency Data) is used\nto override the number of decimal places — and the rounding — according to\nthe currency that is being formatted. That can be seen in the above chart,\nwith the difference between Yen and Euro formatting.","ref":"Cldr.Number.Format.Compiler.html#module-number-pattern-examples"},{"type":"module","title":"Special Pattern Characters - Cldr.Number.Format.Compiler","doc":"Many characters in a pattern are taken literally; they are matched during\nparsing and output unchanged during formatting. Special characters, on the\nother hand, stand for other characters, strings, or classes of characters.\nFor example, the '#' character is replaced by a localized digit for the\nchosen numberSystem. Often the replacement character is the same as the\npattern character; in the U.S. locale, the ',' grouping character is replaced\nby ','. However, the replacement is still happening, and if the symbols are\nmodified, the grouping character changes. Some special characters affect the\nbehavior of the formatter by their presence; for example, if the percent\ncharacter is seen, then the value is multiplied by 100 before being displayed.\n\nTo insert a special character in a pattern as a literal, that is, without any\nspecial meaning, the character must be quoted. There are some exceptions to\nthis which are noted below.","ref":"Cldr.Number.Format.Compiler.html#module-special-pattern-characters"},{"type":"module","title":"Number Pattern Character Definitions - Cldr.Number.Format.Compiler","doc":"Symbol | Meaning\n------ | -------\n0\t     | Digit\n1..9   | '1' through '9' indicate rounding to the nearest `n`\n@\t     | Significant digit\n#\t     | Digit, omitting leading/trailing zeros\n.\t     | Decimal separator or monetary decimal separator\n-\t     | Minus sign\n,\t     | Grouping separator\n+\t     | Prefix positive exponents with localized plus sign\n%\t     | Multiply by 100 and show as percentage\n‰      | Multiply by 1000 and show as per mille (aka “basis points”)\n;\t     | Separates positive and negative subpatterns\n¤      | Any sequence is replaced by the localized currency symbol\n*\t     | Pad escape, precedes pad character\n'\t     | Used to quote special characters in a prefix or suffix\n\nA pattern contains a positive subpattern and may contain a negative\nsubpattern, for example, \"#,##0.00;(#,##0.00)\". Each subpattern has a prefix,\na numeric part, and a suffix. If there is no explicit negative subpattern,\nthe implicit negative subpattern is the ASCII minus sign (-) prefixed to the\npositive subpattern. That is, \"0.00\" alone is equivalent to \"0.00;-0.00\".\n(The data in CLDR is normalized to remove an explicit subpattern where it\nwould be identical to the explicit form.) If there is an explicit negative\nsubpattern, it serves only to specify the negative prefix and suffix; the\nnumber of digits, minimal digits, and other characteristics are ignored in\nthe negative subpattern. That means that \"#,##0.0#;(#)\" has precisely the\nsame result as \"#,##0.0#;(#,##0.0#)\". However in the CLDR data, the format is\nnormalized so that the other characteristics are preserved, just for\nreadability.\n\nNote: The thousands separator and decimal separator in patterns are always\nASCII ',' and '.'. They are substituted by the code with the correct local\nvalues according to other fields in CLDR. The same is true of the - (ASCII\nminus sign) and other special characters listed above.\n\nExtracted from [Unicode number formats in TR35](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Formats)","ref":"Cldr.Number.Format.Compiler.html#module-number-pattern-character-definitions"},{"type":"function","title":"Cldr.Number.Format.Compiler.compile/1","doc":"Parse a number format definition and analyze it.\n\nAfter parsing, reduce the format to a set of metrics\nthat can then be used to format a number.","ref":"Cldr.Number.Format.Compiler.html#compile/1"},{"type":"function","title":"Cldr.Number.Format.Compiler.exponent_sign/1","doc":"","ref":"Cldr.Number.Format.Compiler.html#exponent_sign/1"},{"type":"function","title":"Cldr.Number.Format.Compiler.format_to_metadata/1","doc":"Extract the metadata from the format.\n\nThe metadata is used to generate the formatted output.  A numeric format\nis optional and in such cases no analysis is required.","ref":"Cldr.Number.Format.Compiler.html#format_to_metadata/1"},{"type":"function","title":"Cldr.Number.Format.Compiler.format_to_metadata!/1","doc":"Extract the metadata from the format or raise\nan exception..\n\nThe metadata is used to generate the formatted output.  A numeric format\nis optional and in such cases no analysis is required.","ref":"Cldr.Number.Format.Compiler.html#format_to_metadata!/1"},{"type":"function","title":"Cldr.Number.Format.Compiler.formatting_pipeline/1","doc":"Returns an Elixir AST of a formatting pipeline that\nwhen executed produces the formatted output for a given\nformat string.\n\nNot all formats require all parts of the full formatting\npipeline so by compiling only those parts of the pipeline\nthat are required we produce an optimal code path.","ref":"Cldr.Number.Format.Compiler.html#formatting_pipeline/1"},{"type":"function","title":"Cldr.Number.Format.Compiler.number_match_regex/0","doc":"A regular expression that can be used to split either a number format\nor a number itself.\n\nSince it accepts characters that are not digits (like '#', '@' and\n',') it cannot be used to validate a number.  Its only use is to split\na number or a format into parts for later processing.","ref":"Cldr.Number.Format.Compiler.html#number_match_regex/0"},{"type":"function","title":"Cldr.Number.Format.Compiler.padding_char/1","doc":"","ref":"Cldr.Number.Format.Compiler.html#padding_char/1"},{"type":"function","title":"Cldr.Number.Format.Compiler.parse/1","doc":"Parse a number format definition\n\nUsing a yexx lexer, parse a number format definition into list of\nelements we can then interpret to format a number.","ref":"Cldr.Number.Format.Compiler.html#parse/1"},{"type":"function","title":"Example - Cldr.Number.Format.Compiler.parse/1","doc":"iex> Cldr.Number.Format.Compiler.parse \"¤ #,##0.00;¤-#,##0.00\"\n    {:ok,\n     [positive: [currency: 1, literal: \" \", format: \"#,##0.00\"],\n      negative: [currency: 1, minus: ~c\"-\", format: :same_as_positive]]}","ref":"Cldr.Number.Format.Compiler.html#parse/1-example"},{"type":"function","title":"Cldr.Number.Format.Compiler.placeholder/1","doc":"Returns a number placeholder symbol.\n\n* `symbol` is one of `:decimal`, `group`, `:exponent`,\n`:plus`, `:minus`, `:currency`\n\nThese symbols are used in decimal number format\nand are replaced with locale-specific characters\nduring number formatting.","ref":"Cldr.Number.Format.Compiler.html#placeholder/1"},{"type":"function","title":"Example - Cldr.Number.Format.Compiler.placeholder/1","doc":"iex> Cldr.Number.Format.Compiler.placeholder(:plus)\n    \"+\"","ref":"Cldr.Number.Format.Compiler.html#placeholder/1-example"},{"type":"function","title":"Cldr.Number.Format.Compiler.tokenize/1","doc":"Scan a number format definition\n\nUsing a leex lexer, tokenize a rule definition","ref":"Cldr.Number.Format.Compiler.html#tokenize/1"},{"type":"module","title":"Cldr.Number.Format.Meta","doc":"Describes the metadata that drives\nnumber formatting and provides functions to\nupdate the struct.","ref":"Cldr.Number.Format.Meta.html"},{"type":"module","title":"Format definition - Cldr.Number.Format.Meta","doc":"The `:format` is a keyword list that with two\nelements:\n\n* `:positive` which is a keyword list for\n  formatting a number >= zero\n\n* `:negative` which is a keyword list for\n  formatting negative number\n\nThere are two formats because we can format in\nan accounting style (that is, numbers surrounded\nby `()`) or any other arbitrary style. Typically\nthe format for a negative number is the same as\nthat for a positive number with a prepended\nminus sign.","ref":"Cldr.Number.Format.Meta.html#module-format-definition"},{"type":"module","title":"Localisation of number formatting - Cldr.Number.Format.Meta","doc":"Number formatting is always localised to either\nthe currency processes locale or a locale\nprovided as an option to `Cldr.Number.to_string/3`.\n\nThe metadata is independent of the localisation\nprocess. Signs (`+`/`-`), grouping (`,`), decimal markers\n(`.`) and exponent signs are all localised when\nthe number is formatted.","ref":"Cldr.Number.Format.Meta.html#module-localisation-of-number-formatting"},{"type":"module","title":"Formatting directives - Cldr.Number.Format.Meta","doc":"The formats - positive and negative - are defined\nin the metadata struct, as a keyword list of keywords\nand values.\n\nThe simplest formatting list might be:\n```\n[format: _]`\n```\nThe `:format` keyword indicates\nthat this is where the formatting number will be\nsubstituted into the format pattern.\n\nAnother example would be for formatting a negative\nnumber:\n```\n[minus: _, format: _]\n```\nwhich will format with a localised minus sign\nfollowed by the formatted number. Note that the\nkeyword value for `:minus` and `:format` are\nignored.","ref":"Cldr.Number.Format.Meta.html#module-formatting-directives"},{"type":"module","title":"List of formatting keywords - Cldr.Number.Format.Meta","doc":"The following is the full list of formatting\nkeywords which can be used to format a\nnumber. A `_` in the keyword format is\nused to denote `:dont_care`.\n\n* `[format: _]` inserts the formatted number\n  exclusive of any sign\n\n* `[minus: _]` inserts a localised minus\n  sign\n\n* `[plus: _]` inserts a localised plus sign\n\n* `[percent: _]` inserts a localised percent sign\n\n* `[permille: _]` inserts a localised permille sign\n\n* `[literal: \"string\"]` inserts `string` into the\n  format without any processing\n\n* `[currency: 1..4]` inserts a localised currency\n  symbol of the given `type`.  A `:currency` must be\n  provided as an option to `Cldr.Number.Formatter.Decimal.to_string/4`.\n\n* `[pad: \"char\"]` inserts the correct number of `char`s\n  to pad the number format to the width specified by\n  `:padding_length` in the `%Meta{}` struct. The `:pad`\n  can be anywhere in the format list but it is most\n  typically inserted before or after the `:format`\n  keyword.  The assumption is that the `char` is a single\n  binary character but this is not checked.","ref":"Cldr.Number.Format.Meta.html#module-list-of-formatting-keywords"},{"type":"module","title":"Currency symbol formatting - Cldr.Number.Format.Meta","doc":"Currency are localised and have four ways of being\npresented.  The different types are defined in the\n`[currency: type]` keyword where `type` is an integer\nin the range `1..4`  These types will insert\ninto the final format:\n\n  1. The standard currency symbol like `$`,`¥` or `€`\n  2. The ISO currency code (like `USD` and `JPY`)\n  3. The localised and pluralised currency display name\n     like \"Australian dollar\" or \"Australian dollars\"\n  4. The narrow currency symbol if defined for a locale","ref":"Cldr.Number.Format.Meta.html#module-currency-symbol-formatting"},{"type":"function","title":"Cldr.Number.Format.Meta.new/0","doc":"Returns a new number formatting metadata\nstruct.","ref":"Cldr.Number.Format.Meta.html#new/0"},{"type":"function","title":"Cldr.Number.Format.Meta.put_exponent_digits/2","doc":"Set the number of exponent digits to\nformat.","ref":"Cldr.Number.Format.Meta.html#put_exponent_digits/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_exponent_sign/2","doc":"Set whether to add the sign of the exponent to\nthe format.","ref":"Cldr.Number.Format.Meta.html#put_exponent_sign/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_format/2","doc":"","ref":"Cldr.Number.Format.Meta.html#put_format/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_format/3","doc":"Set the metadata format for the positive\nand negative number format.\n\nNote that this is the parsed format as a simple keyword\nlist, not a binary representation.\n\nIts up to each formatting engine to transform its input\ninto this form.  See `Cldr.Number.Format.Meta` module\ndocumentation for the available keywords.","ref":"Cldr.Number.Format.Meta.html#put_format/3"},{"type":"function","title":"Cldr.Number.Format.Meta.put_fraction_digits/3","doc":"Set the minimum, and optionally maximum, fractional digits to\nformat.","ref":"Cldr.Number.Format.Meta.html#put_fraction_digits/3"},{"type":"function","title":"Cldr.Number.Format.Meta.put_fraction_grouping/2","doc":"","ref":"Cldr.Number.Format.Meta.html#put_fraction_grouping/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_fraction_grouping/3","doc":"Sets the number of digits in a group or\noptionally the first group and subsequent\ngroups for the fractional part of a number.\n\nThe grouping character is defined by the locale\ndefined for the current process or supplied\nas the `:locale` option to `to_string/3`.","ref":"Cldr.Number.Format.Meta.html#put_fraction_grouping/3"},{"type":"function","title":"Cldr.Number.Format.Meta.put_integer_digits/3","doc":"Set the minimum, and optionally maximum, integer digits to\nformat.","ref":"Cldr.Number.Format.Meta.html#put_integer_digits/3"},{"type":"function","title":"Cldr.Number.Format.Meta.put_integer_grouping/2","doc":"","ref":"Cldr.Number.Format.Meta.html#put_integer_grouping/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_integer_grouping/3","doc":"Sets the number of digits in a group or\noptionally the first group and subsequent\ngroups for the integer part of a number.\n\nThe grouping character is defined by the locale\ndefined for the current process or supplied\nas the `:locale` option to `to_string/3`.","ref":"Cldr.Number.Format.Meta.html#put_integer_grouping/3"},{"type":"function","title":"Cldr.Number.Format.Meta.put_multiplier/2","doc":"Sets the multiplier for the number.\n\nBefore formatting, the number is multiplied\nby this amount.  This is useful when\nformatting as a percent or permille.","ref":"Cldr.Number.Format.Meta.html#put_multiplier/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_padding_char/2","doc":"Set the padding character to be used when\npadding the formatted number.","ref":"Cldr.Number.Format.Meta.html#put_padding_char/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_padding_length/2","doc":"","ref":"Cldr.Number.Format.Meta.html#put_padding_length/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_round_nearest_digits/2","doc":"Set the increment to which the number should\nbe rounded.","ref":"Cldr.Number.Format.Meta.html#put_round_nearest_digits/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_scientific_rounding_digits/2","doc":"Set the number of scientific digits to which the number should\nbe rounded.","ref":"Cldr.Number.Format.Meta.html#put_scientific_rounding_digits/2"},{"type":"function","title":"Cldr.Number.Format.Meta.put_significant_digits/3","doc":"Set the minimum, and optionally maximum, significant digits to\nformat.","ref":"Cldr.Number.Format.Meta.html#put_significant_digits/3"},{"type":"type","title":"Cldr.Number.Format.Meta.t/0","doc":"Metadata type that drives how to format a number","ref":"Cldr.Number.Format.Meta.html#t:t/0"},{"type":"module","title":"Cldr.Number.Format.Options","doc":"Functions to validate and transform\noptions that guide number formatting","ref":"Cldr.Number.Format.Options.html"},{"type":"function","title":"Cldr.Number.Format.Options.standard_format/5","doc":"","ref":"Cldr.Number.Format.Options.html#standard_format/5"},{"type":"function","title":"Cldr.Number.Format.Options.validate_options/3","doc":"","ref":"Cldr.Number.Format.Options.html#validate_options/3"},{"type":"type","title":"Cldr.Number.Format.Options.currency_symbol/0","doc":"","ref":"Cldr.Number.Format.Options.html#t:currency_symbol/0"},{"type":"type","title":"Cldr.Number.Format.Options.fixed_format/0","doc":"","ref":"Cldr.Number.Format.Options.html#t:fixed_format/0"},{"type":"type","title":"Cldr.Number.Format.Options.format/0","doc":"","ref":"Cldr.Number.Format.Options.html#t:format/0"},{"type":"type","title":"Cldr.Number.Format.Options.short_format_style/0","doc":"","ref":"Cldr.Number.Format.Options.html#t:short_format_style/0"},{"type":"type","title":"Cldr.Number.Format.Options.t/0","doc":"","ref":"Cldr.Number.Format.Options.html#t:t/0"},{"type":"module","title":"Cldr.Number.Formatter.Currency","doc":"Number formatter for the `:currency` `:long` format.\n\nThis formatter implements formatting a currency in a long form. This\nis not the same as decimal formatting with a currency placeholder.\n\nTo explain the difference, look at the following examples:\n\n    iex> Cldr.Number.to_string 123, TestBackend.Cldr, format: :currency, currency: \"USD\"\n    {:ok, \"$123.00\"}\n\n    iex> Cldr.Number.to_string 123, TestBackend.Cldr, format: :long, currency: \"USD\"\n    {:ok, \"123 US dollars\"}\n\nIn the first example the format is defined by a decimal mask. In this example\nthe format mask comes from:\n\n    iex> {:ok, formats} = Cldr.Number.Format.all_formats_for(\"en\", TestBackend.Cldr)\n    ...> formats.latn.currency\n    \"¤#,##0.00\"\n\nIn the second example we are using a format that combines the number with\na language translation of the currency name.  In this example the format\ncomes from:\n\n    iex> {:ok, formats} = Cldr.Number.Format.all_formats_for(\"en\", TestBackend.Cldr)\n    ...> formats.latn.currency_long\n    %{one: [0, \" \", 1], other: [0, \" \", 1]}\n\nWhere \"{0}\" is replaced with the number formatted using the `:standard`\ndecimal format and \"{1} is replaced with locale-specific name of the\ncurrency adjusted for the locales plural rules.\"\n\n**This module is not part of the public API and is subject\nto change at any time.**","ref":"Cldr.Number.Formatter.Currency.html"},{"type":"module","title":"Cldr.Number.Formatter.Decimal","doc":"Formats a number according to a locale-specific predefined format or a user-defined format.\n\nAs a performance optimization, all decimal formats known at compile time are\ncompiled into function that roughly halves the time to format a number\ncompared to a non-precompiled format.\n\nThe available format styles for a locale can be returned by:\n\n    iex> {:ok, decimal_format_styles} = Cldr.Number.Format.decimal_format_styles_for(\"en\", :latn, TestBackend.Cldr)\n    iex> Enum.sort(decimal_format_styles)\n    [\n      :accounting,\n      :accounting_alpha_next_to_number,\n      :accounting_no_symbol,\n      :currency,\n      :currency_alpha_next_to_number,\n      :currency_long,\n      :currency_no_symbol,\n      :percent,\n      :scientific,\n      :standard\n    ]\n\nThis allows a number to be formatted in a locale-specific way but using\na standard method of describing the purpose of the format.","ref":"Cldr.Number.Formatter.Decimal.html"},{"type":"function","title":"Cldr.Number.Formatter.Decimal.to_string/4","doc":"Formats a number according to a decimal format string.\n\nThis is a lower level formatting function. It is strongly\nadvised to use `Cldr.Number.to_string/2` or even better the\n`MyApp.Cldr.Number.to_string/2` function where `MyApp.Cldr`\nis a Cldr backend module.","ref":"Cldr.Number.Formatter.Decimal.html#to_string/4"},{"type":"function","title":"Arguments - Cldr.Number.Formatter.Decimal.to_string/4","doc":"* `number` is an integer, float or Decimal or a string. A string\n  is used only when composing formats.\n\n* `format` is a format string.  See `Cldr.Number` for further\n  information.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.\n\n* `options` is a `t:Cldr.Number.Format.Options.t/0` of validated options.\n  See `Cldr.Number.to_string/2` for further information.","ref":"Cldr.Number.Formatter.Decimal.html#to_string/4-arguments"},{"type":"module","title":"Cldr.Number.Formatter.Short","doc":"Formats a number according to the locale-specific `:short` formats\n\nThis is best explained by some\nexamples:\n\n    iex> Cldr.Number.to_string 123, TestBackend.Cldr, format: :short\n    {:ok, \"123\"}\n\n    iex> Cldr.Number.to_string 1234, TestBackend.Cldr, format: :short\n    {:ok, \"1K\"}\n\n    iex> Cldr.Number.to_string 523456789, TestBackend.Cldr, format: :short\n    {:ok, \"523M\"}\n\n    iex> Cldr.Number.to_string 7234567890, TestBackend.Cldr, format: :short\n    {:ok, \"7B\"}\n\n    iex> Cldr.Number.to_string 7234567890, TestBackend.Cldr, format: :long\n    {:ok, \"7 billion\"}\n\nThese formats are compact representations however they do lose\nprecision in the presentation in favour of human readability.\n\nNote that for a `:currency` short format the number of decimal places\nis retrieved from the currency definition itself.  You can see the difference\nin the following examples:\n\n    iex> Cldr.Number.to_string 1234, TestBackend.Cldr, format: :short, currency: \"EUR\"\n    {:ok, \"€1K\"}\n\n    iex> Cldr.Number.to_string 1234, TestBackend.Cldr, format: :short, currency: \"EUR\", fractional_digits: 2\n    {:ok, \"€1.23K\"}\n\n    iex> Cldr.Number.to_string 1234, TestBackend.Cldr, format: :short, currency: \"JPY\"\n    {:ok, \"¥1K\"}\n\n**This module is not part of the public API and is subject\nto change at any time.**","ref":"Cldr.Number.Formatter.Short.html"},{"type":"function","title":"Cldr.Number.Formatter.Short.short_format_exponent/2","doc":"Returns the exponent that will be applied\nwhen formatting the given number as a short\nformat.\n\nThis function is primarily intended to support\npluralization for compact numbers (numbers\nformatted with the `format: :short` option) since\nsome languages pluralize compact numbers differently\nto a fully expressed number.\n\nSuch rules are defined for the locale \"fr\" from\nCLDR version 38 with the intention that additional\nrules will be added in later versions.","ref":"Cldr.Number.Formatter.Short.html#short_format_exponent/2"},{"type":"function","title":"Examples - Cldr.Number.Formatter.Short.short_format_exponent/2","doc":"iex> Cldr.Number.Formatter.Short.short_format_exponent 1234\n    {1000, 1}\n\n    iex> Cldr.Number.Formatter.Short.short_format_exponent 12345\n    {10000, 2}\n\n    iex> Cldr.Number.Formatter.Short.short_format_exponent 123456789\n    {100000000, 3}\n\n    iex> Cldr.Number.Formatter.Short.short_format_exponent 123456789, locale: \"th\"\n    {100000000, 3}","ref":"Cldr.Number.Formatter.Short.html#short_format_exponent/2-examples"},{"type":"function","title":"Cldr.Number.Formatter.Short.to_string/4","doc":"","ref":"Cldr.Number.Formatter.Short.html#to_string/4"},{"type":"module","title":"Cldr.Number.Parser","doc":"Functions for parsing numbers and currencies from\na string.","ref":"Cldr.Number.Parser.html"},{"type":"function","title":"Cldr.Number.Parser.find_and_replace/3","doc":"Find a substring at the beginning and/or end of a\nstring, and replace it.\n\nIgnore any whitespace found at the start or end of the\nstring when looking for a match. A match is considered\nonly if there is no alphabetic character adjacent to\nthe match.\n\nWhen multiple matches are found, the longest match\nis replaced.","ref":"Cldr.Number.Parser.html#find_and_replace/3"},{"type":"function","title":"Arguments - Cldr.Number.Parser.find_and_replace/3","doc":"* `string_map` is a map where the keys are the strings\n  to be matched and the values are the replacement.\n\n* `string` is the string in which the find and replace\n  operation takes place.\n\n* `fuzzy` is floating point number between 0.0 and 1.0\n  that is used to implement a fuzzy match using\n  `String.jaro_distance/2`. The default is `nil` which\n  means the match is exact at the beginning and/or the\n  end of the `string`.","ref":"Cldr.Number.Parser.html#find_and_replace/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.Parser.find_and_replace/3","doc":"* `{:ok, list}` where list is `string` broken into the\n  replacement(s) and the remainder after find and replace. Or\n\n* `{:error, {exception, reason}}` will be returned if\n  the `fuzzy` parameter is invalid or if no search was found\n  and no replacement made. In the later case, `exception`\n  will be `Cldr.Number.ParseError`.","ref":"Cldr.Number.Parser.html#find_and_replace/3-returns"},{"type":"function","title":"Examples - Cldr.Number.Parser.find_and_replace/3","doc":"iex> Cldr.Number.Parser.find_and_replace(%{\"this\" => \"that\"}, \"This is a string\")\n    {:ok, [\"that\", \" is a string\"]}\n\n    iex> Cldr.Number.Parser.find_and_replace(%{\"string\" => \"term\"}, \"This is a string\")\n    {:ok, [\"This is a \", \"term\"]}\n\n    iex> Cldr.Number.Parser.find_and_replace(%{\"string\" => \"term\", \"this\" => \"that\"}, \"This is a string\")\n    {:ok, [\"that\", \" is a \", \"term\"]}\n\n    iex> Cldr.Number.Parser.find_and_replace(%{\"unknown\" => \"term\"}, \"This is a string\")\n    {:error, {Cldr.Number.ParseError, \"No match was found\"}}","ref":"Cldr.Number.Parser.html#find_and_replace/3-examples"},{"type":"function","title":"Cldr.Number.Parser.parse/2","doc":"Parse a string in a locale-aware manner and return\na number.","ref":"Cldr.Number.Parser.html#parse/2"},{"type":"function","title":"Arguments - Cldr.Number.Parser.parse/2","doc":"* `string` is any `t:String`\n\n* `options` is a keyword list of options","ref":"Cldr.Number.Parser.html#parse/2-arguments"},{"type":"function","title":"Options - Cldr.Number.Parser.parse/2","doc":"* `:number` is one of `:integer`, `:float`,\n  `:decimal` or `nil`. The default is `nil`\n  meaning that the type auto-detected as either\n  an `integer` or a `float`.\n\n* `:backend` is any module that includes `use Cldr`\n  and is therefore a CLDR backend module. The default\n  is `Cldr.default_backend/0`.\n\n* `:locale` is any locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag.t`. The default is `options[:backend].get_locale/1`.","ref":"Cldr.Number.Parser.html#parse/2-options"},{"type":"function","title":"Returns - Cldr.Number.Parser.parse/2","doc":"* A number of the requested or default type or\n\n* `{:error, {exception, message}}` if no number could be determined","ref":"Cldr.Number.Parser.html#parse/2-returns"},{"type":"function","title":"Notes - Cldr.Number.Parser.parse/2","doc":"This function parses a string to return a number but\nin a locale-aware manner. It will normalise digits,\ngrouping characters and decimal separators.\n\nIt will transliterate digits that are in the\nnumber system of the specific locale. For example, if\nthe locale is `th` (Thailand), then Thai digits are\ntransliterated to the Latin script before parsing.\n\nSome number systems do not have decimal digits and in this\ncase an error will be returned, rather than continue\nparsing and return misleading results.\n\nIt also caters for different forms of\nthe `+` and `-` symbols that appear in Unicode and\nstrips any `_` characters that might be used for\nformatting in a string.\n\nIt then parses the number using the Elixir standard\nlibrary functions.\n\nIf the option `:number` is used and the parsed number\ncannot be coerced to this type without losing precision\nthen an error is returned.","ref":"Cldr.Number.Parser.html#parse/2-notes"},{"type":"function","title":"Examples - Cldr.Number.Parser.parse/2","doc":"iex> Cldr.Number.Parser.parse(\"＋1.000,34\", locale: \"de\")\n    {:ok, 1000.34}\n\n    iex> Cldr.Number.Parser.parse(\"-1_000_000.34\")\n    {:ok, -1000000.34}\n\n    iex> Cldr.Number.Parser.parse(\"1.000\", locale: \"de\", number: :integer)\n    {:ok, 1000}\n\n    iex> Cldr.Number.Parser.parse \"١٢٣٤٥\", locale: \"ar\"\n    {:ok, 12345}\n\n    # 1_000.34 cannot be coerced into an integer\n    # without precision loss so an error is returned.\n    iex> Cldr.Number.Parser.parse(\"＋1.000,34\", locale: \"de\", number: :integer)\n    {:error,\n      {Cldr.Number.ParseError,\n       \"The string \\\"＋1.000,34\\\" could not be parsed as a number\"}}\n\n    iex> Cldr.Number.Parser.parse \"一万二千三百四十五\", locale: \"ja-u-nu-jpan\"\n    {:error, {Cldr.UnknownNumberSystemError, \"The number system :jpan does not have digits\"}}","ref":"Cldr.Number.Parser.html#parse/2-examples"},{"type":"function","title":"Cldr.Number.Parser.remove_whitespace_between_tokens/1","doc":"Removes any whitespace strings from between\ntokens in a list.\n\nTokens are numbers or atoms.","ref":"Cldr.Number.Parser.html#remove_whitespace_between_tokens/1"},{"type":"function","title":"Cldr.Number.Parser.resolve/3","doc":"Maps a list of terms (usually strings and atoms)\ncalling a resolver function that operates\non each binary term.\n\nIf the resolver function returns `{:error, term}`\nthen no change is made to the term, otherwise\nthe return value of the resolver replaces the\noriginal term.","ref":"Cldr.Number.Parser.html#resolve/3"},{"type":"function","title":"Arguments - Cldr.Number.Parser.resolve/3","doc":"* `list` is a list of terms. Typically this is the\n  result of calling `Cldr.Number.Parser.scan/1`.\n\n* `resolver` is a function that takes two\n  arguments. The first is one of the terms\n  in the `list`. The second is `options`.\n\n* `options` is a keyword list of options\n  that is passed to the resolver function.","ref":"Cldr.Number.Parser.html#resolve/3-arguments"},{"type":"function","title":"Note - Cldr.Number.Parser.resolve/3","doc":"* The resolver is called only on binary\n  elements of the list.","ref":"Cldr.Number.Parser.html#resolve/3-note"},{"type":"function","title":"Returns - Cldr.Number.Parser.resolve/3","doc":"* `list` as modified through the application\n  of the resolver function on each binary term.","ref":"Cldr.Number.Parser.html#resolve/3-returns"},{"type":"function","title":"Examples - Cldr.Number.Parser.resolve/3","doc":"See `Cldr.Number.Parser.resolve_currencies/2` and\n`Cldr.Number.Parser.resolve_pers/2` which both\nuse this function.","ref":"Cldr.Number.Parser.html#resolve/3-examples"},{"type":"function","title":"Cldr.Number.Parser.resolve_currencies/2","doc":"Resolve curencies from strings within\na list.\n\nCurrencies can be identified at the\nbeginning and/or the end of a string.","ref":"Cldr.Number.Parser.html#resolve_currencies/2"},{"type":"function","title":"Arguments - Cldr.Number.Parser.resolve_currencies/2","doc":"* `list` is any list in which currency\n  names and symbols are expected\n\n* `options` is a keyword list of options","ref":"Cldr.Number.Parser.html#resolve_currencies/2-arguments"},{"type":"function","title":"Options - Cldr.Number.Parser.resolve_currencies/2","doc":"* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Cldr.default_backend!/0`\n\n* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `t:Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `options[:backend].get_locale()`\n\n* `:only` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be considered for a match.\n  The equates to a list of acceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:except` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be not considered for a match.\n  This equates to a list of unacceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:fuzzy` is a float greater than `0.0` and less than or\n  equal to `1.0` which is used as input to\n  `String.jaro_distance/2` to determine is the provided\n  currency string is *close enough* to a known currency\n  string for it to identify definitively a currency code.\n  It is recommended to use numbers greater than `0.8` in\n  order to reduce false positives.","ref":"Cldr.Number.Parser.html#resolve_currencies/2-options"},{"type":"function","title":"Returns - Cldr.Number.Parser.resolve_currencies/2","doc":"* An ISO4217 currency code as an atom or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Number.Parser.html#resolve_currencies/2-returns"},{"type":"function","title":"Notes - Cldr.Number.Parser.resolve_currencies/2","doc":"The `:only` and `:except` options accept a list of\ncurrency codes and/or currency types.  The following\ntypes are recognised.\n\nIf both `:only` and `:except` are specified,\nthe `:except` entries take priority - that means\nany entries in `:except` are removed from the `:only`\nentries.\n\n  * `:all`, the default, considers all currencies\n\n  * `:current` considers those currencies that have a `:to`\n    date of nil and which also is a known ISO4217 currency\n\n  * `:historic` is the opposite of `:current`\n\n  * `:tender` considers currencies that are legal tender\n\n  * `:unannotated` considers currencies that don't have\n    \"(some string)\" in their names.  These are usually\n    financial instruments.","ref":"Cldr.Number.Parser.html#resolve_currencies/2-notes"},{"type":"function","title":"Examples - Cldr.Number.Parser.resolve_currencies/2","doc":"iex> Cldr.Number.Parser.scan(\"100 US dollars\")\n    ...> |> Cldr.Number.Parser.resolve_currencies\n    [100, :USD]\n\n    iex> Cldr.Number.Parser.scan(\"100 eurosports\")\n    ...> |> Cldr.Number.Parser.resolve_currencies(fuzzy: 0.8)\n    [100, :EUR]\n\n    iex> Cldr.Number.Parser.scan(\"100 dollars des États-Unis\")\n    ...> |> Cldr.Number.Parser.resolve_currencies(locale: \"fr\")\n    [100, :USD]","ref":"Cldr.Number.Parser.html#resolve_currencies/2-examples"},{"type":"function","title":"Cldr.Number.Parser.resolve_currency/2","doc":"Resolve a currency from the beginning\nand/or the end of a string","ref":"Cldr.Number.Parser.html#resolve_currency/2"},{"type":"function","title":"Arguments - Cldr.Number.Parser.resolve_currency/2","doc":"* `list` is any list in which currency\n  names and symbols are expected\n\n* `options` is a keyword list of options","ref":"Cldr.Number.Parser.html#resolve_currency/2-arguments"},{"type":"function","title":"Options - Cldr.Number.Parser.resolve_currency/2","doc":"* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Cldr.default_backend!/0`\n\n* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `options[:backend].get_locale()`\n\n* `:only` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be considered for a match.\n  The equates to a list of acceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:except` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be not considered for a match.\n  This equates to a list of unacceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:fuzzy` is a float greater than `0.0` and less than or\n  equal to `1.0` which is used as input to\n  `String.jaro_distance/2` to determine is the provided\n  currency string is *close enough* to a known currency\n  string for it to identify definitively a currency code.\n  It is recommended to use numbers greater than `0.8` in\n  order to reduce false positives.","ref":"Cldr.Number.Parser.html#resolve_currency/2-options"},{"type":"function","title":"Returns - Cldr.Number.Parser.resolve_currency/2","doc":"* An ISO417 currency code as an atom or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Number.Parser.html#resolve_currency/2-returns"},{"type":"function","title":"Notes - Cldr.Number.Parser.resolve_currency/2","doc":"The `:only` and `:except` options accept a list of\ncurrency codes and/or currency types.  The following\ntypes are recognised.\n\nIf both `:only` and `:except` are specified,\nthe `:except` entries take priority - that means\nany entries in `:except` are removed from the `:only`\nentries.\n\n  * `:all`, the default, considers all currencies\n\n  * `:current` considers those currencies that have a `:to`\n    date of nil and which also is a known ISO4217 currency\n\n  * `:historic` is the opposite of `:current`\n\n  * `:tender` considers currencies that are legal tender\n\n  * `:unannotated` considers currencies that don't have\n    \"(some string)\" in their names.  These are usually\n    financial instruments.","ref":"Cldr.Number.Parser.html#resolve_currency/2-notes"},{"type":"function","title":"Examples - Cldr.Number.Parser.resolve_currency/2","doc":"iex> Cldr.Number.Parser.resolve_currency(\"US dollars\")\n    [:USD]\n\n    iex> Cldr.Number.Parser.resolve_currency(\"100 eurosports\", fuzzy: 0.75)\n    [:EUR]\n\n    iex> Cldr.Number.Parser.resolve_currency(\"dollars des États-Unis\", locale: \"fr\")\n    [:USD]\n\n    iex> Cldr.Number.Parser.resolve_currency(\"not a known currency\", locale: \"fr\")\n    {:error,\n     {Cldr.UnknownCurrencyError,\n      \"The currency \\\"not a known currency\\\" is unknown or not supported\"}}","ref":"Cldr.Number.Parser.html#resolve_currency/2-examples"},{"type":"function","title":"Cldr.Number.Parser.resolve_per/2","doc":"Resolve and tokenize percent or permille\nfrom the beginning and/or the end of a string","ref":"Cldr.Number.Parser.html#resolve_per/2"},{"type":"function","title":"Arguments - Cldr.Number.Parser.resolve_per/2","doc":"* `list` is any list in which percent\n  and permille symbols are expected\n\n* `options` is a keyword list of options","ref":"Cldr.Number.Parser.html#resolve_per/2-arguments"},{"type":"function","title":"Options - Cldr.Number.Parser.resolve_per/2","doc":"* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Cldr.default_backend!/0`\n\n* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `options[:backend].get_locale()`","ref":"Cldr.Number.Parser.html#resolve_per/2-options"},{"type":"function","title":"Returns - Cldr.Number.Parser.resolve_per/2","doc":"* An `:percent` or `permille` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Number.Parser.html#resolve_per/2-returns"},{"type":"function","title":"Examples - Cldr.Number.Parser.resolve_per/2","doc":"iex> Cldr.Number.Parser.resolve_per \"11%\"\n    [\"11\", :percent]\n\n    iex> Cldr.Number.Parser.resolve_per \"% of linguists\"\n    [:percent, \" of linguists\"]\n\n    iex> Cldr.Number.Parser.resolve_per \"% of linguists %\"\n    [:percent, \" of linguists \", :percent]","ref":"Cldr.Number.Parser.html#resolve_per/2-examples"},{"type":"function","title":"Cldr.Number.Parser.resolve_pers/2","doc":"Resolve and tokenize percent and permille\nsybols from strings within a list.\n\nPercent and permille symbols can be identified\nat the beginning and/or the end of a string.","ref":"Cldr.Number.Parser.html#resolve_pers/2"},{"type":"function","title":"Arguments - Cldr.Number.Parser.resolve_pers/2","doc":"* `list` is any list in which percent and\n  permille symbols are expected\n\n* `options` is a keyword list of options","ref":"Cldr.Number.Parser.html#resolve_pers/2-arguments"},{"type":"function","title":"Options - Cldr.Number.Parser.resolve_pers/2","doc":"* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Cldr.default_backend!/0`\n\n* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `t:Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `options[:backend].get_locale()`","ref":"Cldr.Number.Parser.html#resolve_pers/2-options"},{"type":"function","title":"Examples - Cldr.Number.Parser.resolve_pers/2","doc":"iex> Cldr.Number.Parser.scan(\"100%\")\n    ...> |> Cldr.Number.Parser.resolve_pers()\n    [100, :percent]","ref":"Cldr.Number.Parser.html#resolve_pers/2-examples"},{"type":"function","title":"Cldr.Number.Parser.scan/2","doc":"Scans a string in a locale-aware manner and returns\na list of strings and numbers.","ref":"Cldr.Number.Parser.html#scan/2"},{"type":"function","title":"Arguments - Cldr.Number.Parser.scan/2","doc":"* `string` is any `String.t`\n\n* `options` is a keyword list of options","ref":"Cldr.Number.Parser.html#scan/2-arguments"},{"type":"function","title":"Options - Cldr.Number.Parser.scan/2","doc":"* `:number` is one of `:integer`, `:float`,\n  `:decimal` or `nil`. The default is `nil`\n  meaning that the type auto-detected as either\n  an `integer` or a `float`.\n\n* `:backend` is any module that includes `use Cldr`\n  and is therefore a CLDR backend module. The default\n  is `Cldr.default_backend!/0`.\n\n* `:locale` is any locale returned by `Cldr.known_locale_names/1`\n  or a `t:Cldr.LanguageTag`. The default is `options[:backend].get_locale/1`.","ref":"Cldr.Number.Parser.html#scan/2-options"},{"type":"function","title":"Returns - Cldr.Number.Parser.scan/2","doc":"* A list of strings and numbers","ref":"Cldr.Number.Parser.html#scan/2-returns"},{"type":"function","title":"Notes - Cldr.Number.Parser.scan/2","doc":"Number parsing is performed by `Cldr.Number.Parser.parse/2`\nand any options provided are passed to that function.","ref":"Cldr.Number.Parser.html#scan/2-notes"},{"type":"function","title":"Examples - Cldr.Number.Parser.scan/2","doc":"iex> Cldr.Number.Parser.scan(\"£1_000_000.34\")\n    [\"£\", 1000000.34]\n\n    iex> Cldr.Number.Parser.scan(\"I want £1_000_000 dollars\")\n    [\"I want £\", 1000000, \" dollars\"]\n\n    iex> Cldr.Number.Parser.scan(\"The prize is 23\")\n    [\"The prize is \", 23]\n\n    iex> Cldr.Number.Parser.scan(\"The lottery number is 23 for the next draw\")\n    [\"The lottery number is \", 23, \" for the next draw\"]\n\n    iex> Cldr.Number.Parser.scan(\"The loss is -1.000 euros\", locale: \"de\", number: :integer)\n    [\"The loss is \", -1000, \" euros\"]\n\n    iex> Cldr.Number.Parser.scan \"1kg\"\n    [1, \"kg\"]\n\n    iex> Cldr.Number.Parser.scan \"A number is the arab script ١٢٣٤٥\", locale: \"ar\"\n    [\"A number is the arab script \", 12345]","ref":"Cldr.Number.Parser.html#scan/2-examples"},{"type":"type","title":"Cldr.Number.Parser.per/0","doc":"","ref":"Cldr.Number.Parser.html#t:per/0"},{"type":"module","title":"Cldr.Number.Symbol","doc":"Functions to manage the symbol definitions for a locale and\nnumber system.","ref":"Cldr.Number.Symbol.html"},{"type":"function","title":"Cldr.Number.Symbol.all_decimal_symbols/1","doc":"Returns a list of all decimal symbols defined\nby the locales configured in the given backend as\na list.","ref":"Cldr.Number.Symbol.html#all_decimal_symbols/1"},{"type":"function","title":"Arguments - Cldr.Number.Symbol.all_decimal_symbols/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.Symbol.html#all_decimal_symbols/1-arguments"},{"type":"function","title":"Cldr.Number.Symbol.all_decimal_symbols_class/1","doc":"Returns a list of all decimal symbols defined\nby the locales configured in the given backend as\na string.\n\nThis string can be used as a character class\nwhen builing a regular expression.","ref":"Cldr.Number.Symbol.html#all_decimal_symbols_class/1"},{"type":"function","title":"Arguments - Cldr.Number.Symbol.all_decimal_symbols_class/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.Symbol.html#all_decimal_symbols_class/1-arguments"},{"type":"function","title":"Cldr.Number.Symbol.all_grouping_symbols/1","doc":"Returns a list of all grouping symbols defined\nby the locales configured in the given backend as\na list.","ref":"Cldr.Number.Symbol.html#all_grouping_symbols/1"},{"type":"function","title":"Arguments - Cldr.Number.Symbol.all_grouping_symbols/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.Symbol.html#all_grouping_symbols/1-arguments"},{"type":"function","title":"Cldr.Number.Symbol.all_grouping_symbols_class/1","doc":"Returns a list of all grouping symbols defined\nby the locales configured in the given backend as\na string.\n\nThis string can be used as a character class\nwhen builing a regular expression.","ref":"Cldr.Number.Symbol.html#all_grouping_symbols_class/1"},{"type":"function","title":"Arguments - Cldr.Number.Symbol.all_grouping_symbols_class/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.Symbol.html#all_grouping_symbols_class/1-arguments"},{"type":"function","title":"Cldr.Number.Symbol.number_symbols_for/2","doc":"Returns a map of `Cldr.Number.Symbol.t` structs of the number symbols for each\nof the number systems of a locale.","ref":"Cldr.Number.Symbol.html#number_symbols_for/2"},{"type":"function","title":"Arguments - Cldr.Number.Symbol.number_symbols_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.  The\n  default is `Cldr.get_locale/1`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.Symbol.html#number_symbols_for/2-arguments"},{"type":"function","title":"Example: - Cldr.Number.Symbol.number_symbols_for/2","doc":"iex> Cldr.Number.Symbol.number_symbols_for(\"th\", TestBackend.Cldr)\n    {:ok, %{\n       latn: %Cldr.Number.Symbol{\n         decimal: \".\",\n         exponential: \"E\",\n         group: \",\",\n         infinity: \"∞\",\n         list: \";\",\n         minus_sign: \"-\",\n         nan: \"NaN\",\n         per_mille: \"‰\",\n         percent_sign: \"%\",\n         plus_sign: \"+\",\n         superscripting_exponent: \"×\",\n         time_separator: \":\"\n       },\n       thai: %Cldr.Number.Symbol{\n         decimal: \".\",\n         exponential: \"E\",\n         group: \",\",\n         infinity: \"∞\",\n         list: \";\",\n         minus_sign: \"-\",\n         nan: \"NaN\",\n         per_mille: \"‰\",\n         percent_sign: \"%\",\n         plus_sign: \"+\",\n         superscripting_exponent: \"×\",\n         time_separator: \":\"\n       }\n     }}","ref":"Cldr.Number.Symbol.html#number_symbols_for/2-example"},{"type":"function","title":"Cldr.Number.Symbol.number_symbols_for/3","doc":"Returns the number symbols for a specific locale and number system.","ref":"Cldr.Number.Symbol.html#number_symbols_for/3"},{"type":"function","title":"Options - Cldr.Number.Symbol.number_symbols_for/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.  The\n  default is `Cldr.get_locale/1`.\n\n* `number_system` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Number.Symbol.html#number_symbols_for/3-options"},{"type":"function","title":"Example - Cldr.Number.Symbol.number_symbols_for/3","doc":"iex> Cldr.Number.Symbol.number_symbols_for(\"th\", \"thai\", TestBackend.Cldr)\n    {:ok, %Cldr.Number.Symbol{\n       decimal: \".\",\n       exponential: \"E\",\n       group: \",\",\n       infinity: \"∞\",\n       list: \";\",\n       minus_sign: \"-\",\n       nan: \"NaN\",\n       per_mille: \"‰\",\n       percent_sign: \"%\",\n       plus_sign: \"+\",\n       superscripting_exponent: \"×\",\n       time_separator: \":\"\n     }}","ref":"Cldr.Number.Symbol.html#number_symbols_for/3-example"},{"type":"type","title":"Cldr.Number.Symbol.t/0","doc":"","ref":"Cldr.Number.Symbol.html#t:t/0"},{"type":"module","title":"Cldr.Number.System","doc":"Number systems information is used to define different representations\nfor numeric values to an end user. Numbering systems are defined in CLDR\nas one of two different types: algorithmic and numeric.\n\nNumeric systems are simply a decimal based system that uses a\npredefined set of digits to represent numbers. Examples are\nWestern digits (ASCII digits), Thai digits, Devanagari digits.\n\nAlgorithmic systems are more complex in nature, since the proper\nformatting and presentation of a numeric quantity is based on some\nalgorithm or set of rules. Examples are Chinese numerals, Hebrew numerals,\nor Roman numerals.\n\nIn CLDR, the rules for presentation of numbers in an algorithmic system\nare defined using the rules based number formats (RBNF) which are\nimplemented in `Cldr.Number.Rbnf`.","ref":"Cldr.Number.System.html"},{"type":"module","title":"Number system attributes - Cldr.Number.System","doc":"Attributes for a number system map are as follows:\n\n* `:id` specifies the name of the number system that can be used to designate\n  its use in formatting.\n* `:type` specifies whether the number system is algorithmic or numeric.\n* `:digits`For numeric systems, specifies the digits used to represent numbers,\n  in order, starting from zero.\n* `:rules` specifies the RBNF ruleset to be used for formatting numbers from this\n  number system. The rules specifier can contain simply a ruleset name, in\n  which case the ruleset is assumed to be found in the rule set grouping\n  \"NumberingSystemRules\". Alternatively, the specifier can denote a specific\n  locale, ruleset grouping, and ruleset name, separated by slashes.\n\nAn example of a number system map is:\n\n    iex> Cldr.Number.System.number_systems()[:latn]\n    %{type: :numeric, digits: \"0123456789\"}\n\n    iex> Cldr.Number.System.number_systems()[:taml]\n    %{type: :algorithmic, rules: \"tamil\"}","ref":"Cldr.Number.System.html#module-number-system-attributes"},{"type":"module","title":"Number system types - Cldr.Number.System","doc":"Each number system also categories number systems into various types:\n\n* `:native` defines the number system used for the native digits,\n   usually defined as a part of the script used to write the language.\n  `:native` number system can only be a numeric positional decimal-digit\n   number system, using digits with General_Category=Decimal_Number. Note\n   that In locales where the native number system is the default, it is\n   assumed that the number system \"latn\" (Western digits 0-9) is always\n   acceptable, and can be selected using the `-nu` keyword as part of a Unicode\n   locale name.\n\n* `:traditional` defines the traditional numerals for a locale. This numbering\n  system may be numeric or algorithmic. If the traditional number system is\n  not defined, the native number system is used as a fallback.\n\n* `:finance` defines the number system used for financial quantities. This\n  number system may be numeric or algorithmic. This is often used for\n  ideographic languages such as Chinese, where it would be easy to alter an amount\n  represented in the default number system simply by adding additional strokes.\n  If the financial number system is not specified, the\n  default number system is used as a fallback.\n\nAn example of a number system map for the `:zh` locale is:\n\n    iex> Cldr.Number.System.number_systems_for(:zh, MyApp.Cldr)\n    {:ok,\n     %{default: :latn, native: :hanidec, traditional: :hans, finance: :hansfin}}\n\nThis indicates that for the locale `:zh`, the number systems `:latn`, `:hanidec`,\n`:hans` and `:hansfin` are supported. These number systems are a mix of\nnuemeric systems and algorithmic systems.","ref":"Cldr.Number.System.html#module-number-system-types"},{"type":"module","title":"Specifying the number system in a locale name - Cldr.Number.System","doc":"The types defined for other number systems can be used in a Unicode locale\nidentifier to select the proper number system without having to know the\nspecific number system by name. For example:\n\n* To select the Hindi language using the native digits for numeric formatting, use\n  locale ID: \"hi-IN-u-nu-native\".\n\n* To select the Chinese language using the appropriate financial numerals, use\n  locale ID: \"zh-u-nu-finance\".\n\n* To select the Tamil language using the traditional Tamil numerals, use\n  locale ID: \"ta-u-nu-traditio\".\n\n* To select the Arabic language using western digits 0-9, use locale ID:\n  \"ar-u-nu-latn\".","ref":"Cldr.Number.System.html#module-specifying-the-number-system-in-a-locale-name"},{"type":"function","title":"Cldr.Number.System.algorithmic_systems/0","doc":"Returns a map of the number systems that are\nalgorithmic.\n\nAlgorithmic number systems don't have decimal\ndigits. Numbers are formed by algorithm using\nrules based number formats.\n\nThe `:rules` field contains the name of the\nRBNF rule that will be used with formatting\na number with `format: :standard` (which is\nalso the default when no `:format` is specified).\n\nSee also `Cldr.Number.System.numeric_systems/0`.","ref":"Cldr.Number.System.html#algorithmic_systems/0"},{"type":"function","title":"Example - Cldr.Number.System.algorithmic_systems/0","doc":"==> Cldr.Number.System.algorithmic_systems()\n    %{\n      roman: %{type: :algorithmic, rules: \"roman-upper\"},\n      armn: %{type: :algorithmic, rules: \"armenian-upper\"},\n      armnlow: %{type: :algorithmic, rules: \"armenian-lower\"},\n      cyrl: %{type: :algorithmic, rules: \"cyrillic-lower\"},\n      ethi: %{type: :algorithmic, rules: \"ethiopic\"},\n      geor: %{type: :algorithmic, rules: \"georgian\"},\n      grek: %{type: :algorithmic, rules: \"greek-upper\"},\n      greklow: %{type: :algorithmic, rules: \"greek-lower\"},\n      hanidays: %{\n        type: :algorithmic,\n        rules: \"zh/SpelloutRules/spellout-numbering-days\"\n      },\n      hans: %{type: :algorithmic, rules: \"zh/SpelloutRules/spellout-cardinal\"},\n      hansfin: %{\n        type: :algorithmic,\n        rules: \"zh/SpelloutRules/spellout-cardinal-financial\"\n      },\n      ...\n    }","ref":"Cldr.Number.System.html#algorithmic_systems/0-example"},{"type":"function","title":"Cldr.Number.System.default_number_system_type/0","doc":"Return the default number system type name.\n\nThe default number system type is `:default`.\nNote that this is not the number system itself but the type of the\nnumber system.","ref":"Cldr.Number.System.html#default_number_system_type/0"},{"type":"function","title":"Example - Cldr.Number.System.default_number_system_type/0","doc":"iex> Cldr.Number.System.default_number_system_type()\n    :default","ref":"Cldr.Number.System.html#default_number_system_type/0-example"},{"type":"function","title":"Cldr.Number.System.default_rbnf_rule/2","doc":"Returns the default RBNF rule name for an\nalgorithmic number system.","ref":"Cldr.Number.System.html#default_rbnf_rule/2"},{"type":"function","title":"Arguments - Cldr.Number.System.default_rbnf_rule/2","doc":"* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`.","ref":"Cldr.Number.System.html#default_rbnf_rule/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.default_rbnf_rule/2","doc":"* `{:ok, {module, rule_function, locale}}` or\n\n* `{:error, {module(), reason}}`","ref":"Cldr.Number.System.html#default_rbnf_rule/2-returns"},{"type":"function","title":"Example - Cldr.Number.System.default_rbnf_rule/2","doc":"iex> Cldr.Number.System.default_rbnf_rule(:taml, MyApp.Cldr)\n    {:ok, {MyApp.Cldr.Rbnf.NumberSystem, :tamil, :und}}\n\n    iex> Cldr.Number.System.default_rbnf_rule(:hebr, MyApp.Cldr)\n    {:ok, {MyApp.Cldr.Rbnf.NumberSystem, :hebrew, :und}}\n\n    iex> Cldr.Number.System.default_rbnf_rule(:jpanfin, MyApp.Cldr)\n    {:ok, {MyApp.Cldr.Rbnf.Spellout, :spellout_cardinal_financial, :ja}}\n\n    iex> Cldr.Number.System.default_rbnf_rule(:latn, MyApp.Cldr)\n    {:error,\n     {Cldr.UnknownNumberSystemError, \"The number system :latn is not algorithmic\"}}","ref":"Cldr.Number.System.html#default_rbnf_rule/2-example"},{"type":"function","title":"Cldr.Number.System.generate_transliteration_map/2","doc":"Generate a transliteration map between two character classes.","ref":"Cldr.Number.System.html#generate_transliteration_map/2"},{"type":"function","title":"Arguments - Cldr.Number.System.generate_transliteration_map/2","doc":"* `from` is any `String.t()` intended to represent the\n  digits of a number system but that's not a requirement.\n\n* `to` is any `String.t()` that is the same length as `from`\n  intended to represent the digits of a number system.","ref":"Cldr.Number.System.html#generate_transliteration_map/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.generate_transliteration_map/2","doc":"* A map where the keys are the graphemes in `from` and the\n  values are the graphemes in `to` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Number.System.html#generate_transliteration_map/2-returns"},{"type":"function","title":"Examples - Cldr.Number.System.generate_transliteration_map/2","doc":"iex> Cldr.Number.System.generate_transliteration_map(\"0123456789\", \"9876543210\")\n    %{\n      \"0\" => \"9\",\n      \"1\" => \"8\",\n      \"2\" => \"7\",\n      \"3\" => \"6\",\n      \"4\" => \"5\",\n      \"5\" => \"4\",\n      \"6\" => \"3\",\n      \"7\" => \"2\",\n      \"8\" => \"1\",\n      \"9\" => \"0\"\n    }\n\n    iex> Cldr.Number.System.generate_transliteration_map(\"0123456789\", \"987654321\")\n    {:error,\n     {ArgumentError, \"\\\"0123456789\\\" and \\\"987654321\\\" aren't the same length\"}}","ref":"Cldr.Number.System.html#generate_transliteration_map/2-examples"},{"type":"function","title":"Cldr.Number.System.known_number_system_types/1","doc":"","ref":"Cldr.Number.System.html#known_number_system_types/1"},{"type":"function","title":"Cldr.Number.System.known_number_systems/0","doc":"","ref":"Cldr.Number.System.html#known_number_systems/0"},{"type":"function","title":"Cldr.Number.System.number_system_digits/1","doc":"Returns the digits for a number system as a\nstring.","ref":"Cldr.Number.System.html#number_system_digits/1"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_digits/1","doc":"* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`","ref":"Cldr.Number.System.html#number_system_digits/1-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_digits/1","doc":"* `{:ok, string_of_digits}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.System.html#number_system_digits/1-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_digits/1","doc":"iex> Cldr.Number.System.number_system_digits(:latn)\n    {:ok, \"0123456789\"}\n\n    iex> Cldr.Number.System.number_system_digits(:nope)\n    {:error, {Cldr.UnknownNumberSystemError, \"The number system :nope is not known\"}}","ref":"Cldr.Number.System.html#number_system_digits/1-examples"},{"type":"function","title":"Cldr.Number.System.number_system_digits!/1","doc":"Returns `digits` for a number system, or raises an exception.","ref":"Cldr.Number.System.html#number_system_digits!/1"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_digits!/1","doc":"* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`","ref":"Cldr.Number.System.html#number_system_digits!/1-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_digits!/1","doc":"* A string of the number systems digits or\n\n* raises an exception","ref":"Cldr.Number.System.html#number_system_digits!/1-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_digits!/1","doc":"iex> Cldr.Number.System.number_system_digits! :latn\n    \"0123456789\"\n\n    Cldr.Number.System.number_system_digits! :nope\n    ** (Cldr.UnknownNumberSystemError) The number system :nope is not known or does not have digits","ref":"Cldr.Number.System.html#number_system_digits!/1-examples"},{"type":"function","title":"Cldr.Number.System.number_system_for/3","doc":"Returns the actual number system from a number system type.","ref":"Cldr.Number.System.html#number_system_for/3"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_for/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`","ref":"Cldr.Number.System.html#number_system_for/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_for/3","doc":"* `{:ok, number_system_map}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.System.html#number_system_for/3-returns"},{"type":"function","title":"Notes - Cldr.Number.System.number_system_for/3","doc":"This function will decode a number system type into the actual\nnumber system.  If the number system provided can't be decoded\nit is returned as is.","ref":"Cldr.Number.System.html#number_system_for/3-notes"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_for/3","doc":"iex> Cldr.Number.System.number_system_for(\"th\", :latn, TestBackend.Cldr)\n    {:ok, %{digits: \"0123456789\", type: :numeric}}\n\n    iex> Cldr.Number.System.number_system_for(\"en\", :default, TestBackend.Cldr)\n    {:ok, %{digits: \"0123456789\", type: :numeric}}\n\n    iex> Cldr.Number.System.number_system_for(\"he\", :traditional, TestBackend.Cldr)\n    {:ok, %{rules: \"hebrew\", type: :algorithmic}}\n\n    iex> Cldr.Number.System.number_system_for(\"en\", :finance, TestBackend.Cldr)\n    {\n      :error,\n      {\n        Cldr.UnknownNumberSystemError,\n        \"The number system :finance is unknown for the locale named :en. Valid number systems are %{default: :latn, native: :latn}\"\n      }\n    }\n\n    iex> Cldr.Number.System.number_system_for(\"en\", :native, TestBackend.Cldr)\n    {:ok, %{digits: \"0123456789\", type: :numeric}}","ref":"Cldr.Number.System.html#number_system_for/3-examples"},{"type":"function","title":"Cldr.Number.System.number_system_from_locale/1","doc":"Returns the number system from a language tag\nor locale name.","ref":"Cldr.Number.System.html#number_system_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_from_locale/1","doc":"* `locale` is any language tag returned be `Cldr.Locale.new/2`","ref":"Cldr.Number.System.html#number_system_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_from_locale/1","doc":"* A number system name as an atom.","ref":"Cldr.Number.System.html#number_system_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_from_locale/1","doc":"iex> {:ok, locale} = MyApp.Cldr.validate_locale(\"en-US-u-nu-thai\")\n    iex> Cldr.Number.System.number_system_from_locale(locale)\n    :thai\n\n    iex> {:ok, locale} = MyApp.Cldr.validate_locale(\"en-US\")\n    iex> Cldr.Number.System.number_system_from_locale(locale)\n    :latn\n\n    iex> Cldr.Number.System.number_system_from_locale(\"ar\")\n    :arab","ref":"Cldr.Number.System.html#number_system_from_locale/1-examples"},{"type":"function","title":"Cldr.Number.System.number_system_from_locale/2","doc":"Returns the default number system from a language tag\nor locale name.","ref":"Cldr.Number.System.html#number_system_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_from_locale/2","doc":"* `locale` is any language tag returned be `Cldr.Locale.new/2`\n  or a locale name in the list returned by `Cldr.known_locale_names/1`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`","ref":"Cldr.Number.System.html#number_system_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_from_locale/2","doc":"* A number system name as an atom.","ref":"Cldr.Number.System.html#number_system_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_from_locale/2","doc":"iex> Cldr.Number.System.number_system_from_locale(\"en-US-u-nu-thai\", MyApp.Cldr)\n    :thai\n\n    iex> Cldr.Number.System.number_system_from_locale(:\"en-US\", MyApp.Cldr)\n    :latn","ref":"Cldr.Number.System.html#number_system_from_locale/2-examples"},{"type":"function","title":"Cldr.Number.System.number_system_names_for/2","doc":"Returns the names of the number systems available for\na locale.","ref":"Cldr.Number.System.html#number_system_names_for/2"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_names_for/2","doc":"* `locale` is any locale returned by `Cldr.Locale.new!/2`.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`.","ref":"Cldr.Number.System.html#number_system_names_for/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_names_for/2","doc":"* `{:ok, list_of_number_system_names}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.System.html#number_system_names_for/2-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_names_for/2","doc":"iex> Cldr.Number.System.number_system_names_for(\"en\", TestBackend.Cldr)\n    {:ok, [:latn]}\n\n    iex> Cldr.Number.System.number_system_names_for(\"th\", TestBackend.Cldr)\n    {:ok, [:latn, :thai]}\n\n    iex> Cldr.Number.System.number_system_names_for(\"he\", TestBackend.Cldr)\n    {:ok, [:latn, :hebr]}\n\n    iex> Cldr.Number.System.number_system_names_for(\"zz\", TestBackend.Cldr)\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zz\\\" is invalid\"}}","ref":"Cldr.Number.System.html#number_system_names_for/2-examples"},{"type":"function","title":"Cldr.Number.System.number_system_names_for!/2","doc":"Returns the names of the number systems available for\na locale or raises an exception.","ref":"Cldr.Number.System.html#number_system_names_for!/2"},{"type":"function","title":"Arguments - Cldr.Number.System.number_system_names_for!/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`.","ref":"Cldr.Number.System.html#number_system_names_for!/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_system_names_for!/2","doc":"* `list_of_number_system_names` or\n\n* raises and exception.","ref":"Cldr.Number.System.html#number_system_names_for!/2-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_system_names_for!/2","doc":"iex> Cldr.Number.System.number_system_names_for!(\"en\", TestBackend.Cldr)\n    [:latn]\n\n    iex> Cldr.Number.System.number_system_names_for!(\"th\", TestBackend.Cldr)\n    [:latn, :thai]\n\n    iex> Cldr.Number.System.number_system_names_for!(\"he\", TestBackend.Cldr)\n    [:latn, :hebr]","ref":"Cldr.Number.System.html#number_system_names_for!/2-examples"},{"type":"function","title":"Cldr.Number.System.number_systems/0","doc":"Return a map of all CLDR number systems and their\ndefinitions.","ref":"Cldr.Number.System.html#number_systems/0"},{"type":"function","title":"Example - Cldr.Number.System.number_systems/0","doc":"iex> Cldr.Number.System.number_systems() |> Enum.count\n    88","ref":"Cldr.Number.System.html#number_systems/0-example"},{"type":"function","title":"Cldr.Number.System.number_systems_for/2","doc":"Returns the number system types mapped to a number\nsystem name for a locale.\n\nWhen formatting a nummber it is acceptable to refer\nto either the nuumber system type or the number system\nname.","ref":"Cldr.Number.System.html#number_systems_for/2"},{"type":"function","title":"Arguments - Cldr.Number.System.number_systems_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``.\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`.","ref":"Cldr.Number.System.html#number_systems_for/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_systems_for/2","doc":"* `{:ok, number_system_map}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.System.html#number_systems_for/2-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_systems_for/2","doc":"iex> Cldr.Number.System.number_systems_for(:en)\n    {:ok, %{default: :latn, native: :latn}}\n\n    iex> Cldr.Number.System.number_systems_for(:th)\n    {:ok, %{default: :latn, native: :thai}}\n\n    iex> Cldr.Number.System.number_systems_for(\"zz\", TestBackend.Cldr)\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zz\\\" is invalid\"}}","ref":"Cldr.Number.System.html#number_systems_for/2-examples"},{"type":"function","title":"Cldr.Number.System.number_systems_for!/2","doc":"Returns the number system types mapped to a number\nsystem name for a locale or raises an exception.","ref":"Cldr.Number.System.html#number_systems_for!/2"},{"type":"function","title":"Arguments - Cldr.Number.System.number_systems_for!/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Number.System.html#number_systems_for!/2-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_systems_for!/2","doc":"* `number_system_map` or\n\n* raises an exception.","ref":"Cldr.Number.System.html#number_systems_for!/2-returns"},{"type":"function","title":"Examples - Cldr.Number.System.number_systems_for!/2","doc":"iex> Cldr.Number.System.number_systems_for!(\"en\")\n    %{default: :latn, native: :latn}\n\n    iex> Cldr.Number.System.number_systems_for!(\"th\", TestBackend.Cldr)\n    %{default: :latn, native: :thai}","ref":"Cldr.Number.System.html#number_systems_for!/2-examples"},{"type":"function","title":"Cldr.Number.System.number_systems_like/3","doc":"Returns locale and number systems that have the same digits and\nseparators as the supplied one.","ref":"Cldr.Number.System.html#number_systems_like/3"},{"type":"function","title":"Arguments - Cldr.Number.System.number_systems_like/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`","ref":"Cldr.Number.System.html#number_systems_like/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.number_systems_like/3","doc":"","ref":"Cldr.Number.System.html#number_systems_like/3-returns"},{"type":"function","title":"Notes - Cldr.Number.System.number_systems_like/3","doc":"* Transliterating between locale & number systems is expensive.  To avoid\n  unnecessary transliteration we look for locale and number systems that have\n  the same digits and separators.  Typically we are comparing to locale \"en\"\n  and number system \"latn\" since this is what the number formatting routines use\n  as placeholders.","ref":"Cldr.Number.System.html#number_systems_like/3-notes"},{"type":"function","title":"Examples - Cldr.Number.System.number_systems_like/3","doc":"==> import Cldr.LanguageTag.Sigil\n    ==> Cldr.Number.System.number_systems_like(:en, :latn, MyApp.Cldr)\n    {:ok,\n      [\n        {~l[en], :latn},\n        {~l[en-IN], :latn},\n        {~l[ta], :latn},\n        {~l[th], :latn},\n        {~l[zh], :latn}\n      ]\n    }","ref":"Cldr.Number.System.html#number_systems_like/3-examples"},{"type":"function","title":"Cldr.Number.System.numeric_systems/0","doc":"Returns a map of the number systems that have\ntheir own digit character representations.\n\nSee also `Cldr.Number.System.algorithmic_systems/0`.","ref":"Cldr.Number.System.html#numeric_systems/0"},{"type":"function","title":"Example - Cldr.Number.System.numeric_systems/0","doc":"==> Cldr.Number.System.numeric_systems()\n    %{\n      gonm: %{type: :numeric, digits: \"𑵐𑵑𑵒𑵓𑵔𑵕𑵖𑵗𑵘𑵙\"},\n      mathdbl: %{type: :numeric, digits: \"𝟘𝟙𝟚𝟛𝟜𝟝𝟞𝟟𝟠𝟡\"},\n      bhks: %{type: :numeric, digits: \"𑱐𑱑𑱒𑱓𑱔𑱕𑱖𑱗𑱘𑱙\"},\n      deva: %{type: :numeric, digits: \"०१२३४५६७८९\"},\n      adlm: %{type: :numeric, digits: \"𞥐𞥑𞥒𞥓𞥔𞥕𞥖𞥗𞥘𞥙\"},\n      telu: %{type: :numeric, digits: \"౦౧౨౩౪౫౬౭౮౯\"},\n      cakm: %{type: :numeric, digits: \"𑄶𑄷𑄸𑄹𑄺𑄻𑄼𑄽𑄾𑄿\"},\n      mathsans: %{\n        type: :numeric,\n        digits: \"𝟢𝟣𝟤𝟥𝟦𝟧𝟨𝟩𝟪𝟫\"\n      },\n      nkoo: %{type: :numeric, digits: \"߀߁߂߃߄߅߆߇߈߉\"},\n      ...\n    }","ref":"Cldr.Number.System.html#numeric_systems/0-example"},{"type":"function","title":"Cldr.Number.System.system_name_from/3","doc":"Returns a number system name for a given locale and number\nsystem reference.","ref":"Cldr.Number.System.html#system_name_from/3"},{"type":"function","title":"Arguments - Cldr.Number.System.system_name_from/3","doc":"* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`.","ref":"Cldr.Number.System.html#system_name_from/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.system_name_from/3","doc":"* `{:ok, number_system_name}` or\n\n* `{:error, {exception, reason}}`.","ref":"Cldr.Number.System.html#system_name_from/3-returns"},{"type":"function","title":"Notes - Cldr.Number.System.system_name_from/3","doc":"Number systems can be references in one of two ways:\n\n* As a number system type such as :default, :native, :traditional and\n  :finance. This allows references to a number system for a locale in a\n  consistent fashion for a given use\n\n* WIth the number system name directly, such as :latn, :arab or any of the\n  other 70 or so\n\nThis function dereferences the supplied `system_name` and returns the\nactual system name.","ref":"Cldr.Number.System.html#system_name_from/3-notes"},{"type":"function","title":"Examples - Cldr.Number.System.system_name_from/3","doc":"ex> Cldr.Number.System.system_name_from(:default, \"en\", TestBackend.Cldr)\n    {:ok, :latn}\n\n    iex> Cldr.Number.System.system_name_from(\"latn\", \"en\", TestBackend.Cldr)\n    {:ok, :latn}\n\n    iex> Cldr.Number.System.system_name_from(:native, \"en\", TestBackend.Cldr)\n    {:ok, :latn}\n\n    iex> Cldr.Number.System.system_name_from(:nope, \"en\", TestBackend.Cldr)\n    {\n      :error,\n      {Cldr.UnknownNumberSystemError, \"The number system :nope is unknown\"}\n    }\n\nNote that return value is not guaranteed to be a valid\nnumber system for the given locale as demonstrated in the third example.","ref":"Cldr.Number.System.html#system_name_from/3-examples"},{"type":"function","title":"Cldr.Number.System.system_name_from!/3","doc":"Returns a number system name for a given locale and number system\nreference or raises an exception.","ref":"Cldr.Number.System.html#system_name_from!/3"},{"type":"function","title":"Arguments - Cldr.Number.System.system_name_from!/3","doc":"* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`.","ref":"Cldr.Number.System.html#system_name_from!/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.system_name_from!/3","doc":"* `number_system_name` or\n\n* raises an exception.","ref":"Cldr.Number.System.html#system_name_from!/3-returns"},{"type":"function","title":"Examples - Cldr.Number.System.system_name_from!/3","doc":"iex> Cldr.Number.System.system_name_from!(:default, \"en\", TestBackend.Cldr)\n    :latn\n\n    iex> Cldr.Number.System.system_name_from!(\"latn\", \"en\", TestBackend.Cldr)\n    :latn\n\n    iex> Cldr.Number.System.system_name_from!(:traditional, \"he\", TestBackend.Cldr)\n    :hebr","ref":"Cldr.Number.System.html#system_name_from!/3-examples"},{"type":"function","title":"Cldr.Number.System.systems_with_digits/0","doc":"","ref":"Cldr.Number.System.html#systems_with_digits/0"},{"type":"function","title":"Cldr.Number.System.to_system/3","doc":"Converts a number into the representation of\na non-latin number system.\n\nThis function converts numbers to a known\nnumber system only, it does not provide number\nformatting.","ref":"Cldr.Number.System.html#to_system/3"},{"type":"function","title":"Arguments - Cldr.Number.System.to_system/3","doc":"* `number` is a `float`, `integer` or `Decimal`\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`","ref":"Cldr.Number.System.html#to_system/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.to_system/3","doc":"* `{:ok, string_of_digits}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Number.System.html#to_system/3-returns"},{"type":"function","title":"Notes - Cldr.Number.System.to_system/3","doc":"There are two types of number systems in CLDR:\n\n* `:numeric` in which the number system defines\n  a direct mapping between the latin digits `0..9`\n  into a the number system equivalent.  In this case,\n` to_system/3` invokes `Cldr.Number.Transliterate.transliterate_digits/3`\n  for the given number.\n\n* `:algorithmic` in which the number system\n  does not have the same structure as the `:latn`\n  number system and therefore the conversion is\n  done algorithmically.  For CLDR the algorithm\n  is implemented through `Cldr.Rbnf` rulesets.\n  These rulesets are considered by CLDR to be\n  less rigorous than the `:numeric` number systems\n  and caution and testing for a specific use case\n  is recommended.","ref":"Cldr.Number.System.html#to_system/3-notes"},{"type":"function","title":"Examples - Cldr.Number.System.to_system/3","doc":"iex> Cldr.Number.System.to_system(123456, :hebr, TestBackend.Cldr)\n    {:ok, \"קכ״ג׳תנ״ו\"}\n\n    iex> Cldr.Number.System.to_system(123, :hans, TestBackend.Cldr)\n    {:ok, \"一百二十三\"}\n\n    iex> Cldr.Number.System.to_system(123, :hant, TestBackend.Cldr)\n    {:ok, \"一百二十三\"}\n\n    iex> Cldr.Number.System.to_system(123, :hansfin, TestBackend.Cldr)\n    {:ok, \"壹佰贰拾叁\"}","ref":"Cldr.Number.System.html#to_system/3-examples"},{"type":"function","title":"Cldr.Number.System.to_system!/3","doc":"Converts a number into the representation of\na non-latin number system or raises an exception.","ref":"Cldr.Number.System.html#to_system!/3"},{"type":"function","title":"Arguments - Cldr.Number.System.to_system!/3","doc":"* `number` is a `float`, `integer` or `Decimal`\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\n* `backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`","ref":"Cldr.Number.System.html#to_system!/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.to_system!/3","doc":"* `string_of_digits` or\n\n* raises an exception\n\nSee `Cldr.Number.System.to_system/3` for further\ninformation.","ref":"Cldr.Number.System.html#to_system!/3-returns"},{"type":"function","title":"Examples - Cldr.Number.System.to_system!/3","doc":"iex> Cldr.Number.System.to_system!(123, :hans, TestBackend.Cldr)\n    \"一百二十三\"\n\n    iex> Cldr.Number.System.to_system!(123, :hant, TestBackend.Cldr)\n    \"一百二十三\"\n\n    iex> Cldr.Number.System.to_system!(123, :hansfin, TestBackend.Cldr)\n    \"壹佰贰拾叁\"","ref":"Cldr.Number.System.html#to_system!/3-examples"},{"type":"function","title":"Cldr.Number.System.unknown_number_system_for_locale_error/3","doc":"Returns an error tuple for an number system unknown to a given locale.","ref":"Cldr.Number.System.html#unknown_number_system_for_locale_error/3"},{"type":"function","title":"Arguments - Cldr.Number.System.unknown_number_system_for_locale_error/3","doc":"* `number_system` is any number system name **not** returned by `Cldr.known_number_systems/0`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `valid_number_systems` is a map returned by `Cldr.Number.System.number_systems_for/2`.","ref":"Cldr.Number.System.html#unknown_number_system_for_locale_error/3-arguments"},{"type":"function","title":"Returns - Cldr.Number.System.unknown_number_system_for_locale_error/3","doc":"* `{Cldr.UnknownNumberSystemError, reason}`","ref":"Cldr.Number.System.html#unknown_number_system_for_locale_error/3-returns"},{"type":"type","title":"Cldr.Number.System.system_name/0","doc":"","ref":"Cldr.Number.System.html#t:system_name/0"},{"type":"type","title":"Cldr.Number.System.types/0","doc":"","ref":"Cldr.Number.System.html#t:types/0"},{"type":"module","title":"Cldr.Number.Transliterate","doc":"Transliteration for digits and separators.\n\nTransliterating a string is an expensive business.  First the string has to\nbe exploded into its component graphemes.  Then for each grapheme we have\nto map to the equivalent in the other `{locale, number_system}`.  Then we\nhave to reassemble the string.\n\nEffort is made to short circuit where possible. Transliteration is not\nrequired for any `{locale, number_system}` that is the same as `{\"en\",\n\"latn\"}` since the implementation uses this combination for the placeholders during\nformatting already. When short circuiting is possible (typically the en-*\nlocales with \"latn\" number_system - the total number of short circuited\nlocales is 211 of the 537 in CLDR) the overall number formatting is twice as\nfast than when formal transliteration is required.","ref":"Cldr.Number.Transliterate.html"},{"type":"module","title":"Configuring precompilation of digit transliterations - Cldr.Number.Transliterate","doc":"This module includes `Cldr.Number.Transliterate.transliterate_digits/3` which transliterates\ndigits between number systems.  For example from :arabic to :latn.  Since generating a\ntransliteration map is slow, pairs of transliterations can be configured so that the\ntransliteration map is created at compile time and therefore speeding up transliteration at\nrun time.\n\nTo configure these transliteration pairs, add the following to your backend configuration:\n\n    defmodule MyApp.Cldr do\n      use Cldr,\n      locale: [\"en\", \"fr\", \"th\"],\n      default_locale: \"en\",\n      precompile_transliterations: [{:latn, :thai}, {:arab, :thai}]\n    end\n\nWhere each tuple in the list configures one transliteration map.  In this example, two maps are\nconfigured: from :latn to :thai and from :arab to :thai.\n\nA list of configurable number systems is returned by `Cldr.Number.System.numeric_systems/0`.\n\nIf a transliteration is requested between two number pairs that have not been configured for\nprecompilation, a warning is logged.","ref":"Cldr.Number.Transliterate.html#module-configuring-precompilation-of-digit-transliterations"},{"type":"function","title":"Cldr.Number.Transliterate.transliterate/4","doc":"Transliterates from latin digits to another number system's digits.\n\nTransliterates the latin digits 0..9 to their equivalents in\nanother number system. Also transliterates the decimal and grouping\nseparators as well as the plus, minus and exponent symbols. Any other character\nin the string will be returned \"as is\".\n\n* `sequence` is the string to be transliterated.\n\n* `locale` is any known locale, defaulting to `Cldr.get_locale/0`.\n\n* `number_system` is any known number system. If expressed as a `string` it\n  is the actual name of a known number system. If epressed as an `atom` it is\n  used as a key to look up a number system for the locale (the usual keys are\n  `:default` and `:native` but :traditional and :finance are also part of the\n  standard). See `Cldr.Number.System.number_systems_for/2` for a locale to\n  see what number system types are defined. The default is `:default`.\n\nFor available number systems see `Cldr.Number.System.number_systems/0`\nand `Cldr.Number.System.number_systems_for/2`.  Also see\n`Cldr.Number.Symbol.number_symbols_for/2`.","ref":"Cldr.Number.Transliterate.html#transliterate/4"},{"type":"function","title":"Examples - Cldr.Number.Transliterate.transliterate/4","doc":"iex> Cldr.Number.Transliterate.transliterate(\"123556\", \"en\", :default, TestBackend.Cldr)\n    \"123556\"\n\n    iex> Cldr.Number.Transliterate.transliterate(\"123,556.000\", \"fr\", :default, TestBackend.Cldr)\n    \"123 556,000\"\n\n    iex> Cldr.Number.Transliterate.transliterate(\"123556\", \"th\", :default, TestBackend.Cldr)\n    \"123556\"\n\n    iex> Cldr.Number.Transliterate.transliterate(\"123556\", \"th\", \"thai\", TestBackend.Cldr)\n    \"๑๒๓๕๕๖\"\n\n    iex> Cldr.Number.Transliterate.transliterate(\"123556\", \"th\", :native, TestBackend.Cldr)\n    \"๑๒๓๕๕๖\"\n\n    iex> Cldr.Number.Transliterate.transliterate(\"Some number is: 123556\", \"th\", \"thai\", TestBackend.Cldr)\n    \"Some number is: ๑๒๓๕๕๖\"","ref":"Cldr.Number.Transliterate.html#transliterate/4-examples"},{"type":"function","title":"Cldr.Number.Transliterate.transliterate_digits/3","doc":"","ref":"Cldr.Number.Transliterate.html#transliterate_digits/3"},{"type":"module","title":"Cldr.Rbnf","doc":"Functions to implement Rules Based Number Formatting (rbnf)\n\nDuring compilation RBNF rules are extracted and generated\nas function bodies by `Cldr.Rbnf.Ordinal`, `Cldr.Rbnf.Cardinal`\nand `Cldr.Rbnf.NumberSystem`.\n\nThe functions in this module would not normally be of common\nuse outside of supporting the compilation phase.","ref":"Cldr.Rbnf.html"},{"type":"function","title":"Cldr.Rbnf.for_locale/1","doc":"Returns {:ok, rbnf_rules} for a `locale` or `{:error, {Cldr.NoRbnf, info}}`\n\n* `locale` is any `t:Cldr.LanguageTag`\n\nThis function reads the raw locale definition and therefore\nshould *not* be called at runtime.","ref":"Cldr.Rbnf.html#for_locale/1"},{"type":"function","title":"Cldr.Rbnf.for_locale/2","doc":"Returns {:ok, rbnf_rules} for a `locale` or `{:error, {Cldr.NoRbnf, info}}`\n\n* `locale` is any locale name returned by `Cldr.Rbnf.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Rbnf.html#for_locale/2"},{"type":"function","title":"Cldr.Rbnf.for_locale!/1","doc":"Returns rbnf_rules for a `locale` or raises an exception if\nthere are no rules.\n\n* `locale` is any `Cldr.LanguageTag`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Rbnf.html#for_locale!/1"},{"type":"function","title":"Cldr.Rbnf.for_locale!/2","doc":"Returns rbnf_rules for a `locale` and `backend` or raises an exception if\nthere are no rules.\n\n* `locale` is any locale name returned by `Cldr.Rbnf.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Rbnf.html#for_locale!/2"},{"type":"function","title":"Cldr.Rbnf.known_locale_names/1","doc":"Returns the list of locales that that have RBNF defined\n\nThis list is the set of known locales for which\nthere are rbnf rules defined.\n\nDelegates to `Cldr.known_rbnf_locale_names/1`","ref":"Cldr.Rbnf.html#known_locale_names/1"},{"type":"function","title":"Cldr.Rbnf.rbnf_locale_error/1","doc":"","ref":"Cldr.Rbnf.html#rbnf_locale_error/1"},{"type":"function","title":"Cldr.Rbnf.rbnf_rule_error/2","doc":"","ref":"Cldr.Rbnf.html#rbnf_rule_error/2"},{"type":"function","title":"Cldr.Rbnf.rule_names_for_locale/1","doc":"Returns the list of RBNF rules for a locale.\n\nA rule name can be used as the `:format` parameter\nin `Cldr.Number.to_string/3`.","ref":"Cldr.Rbnf.html#rule_names_for_locale/1"},{"type":"function","title":"Arguments - Cldr.Rbnf.rule_names_for_locale/1","doc":"* `locale` is any `Cldr.LanguageTag.t()`","ref":"Cldr.Rbnf.html#rule_names_for_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Rbnf.rule_names_for_locale/1","doc":"* `{:ok, [list_of_rule_names_as_atoms]}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Rbnf.html#rule_names_for_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Rbnf.rule_names_for_locale/1","doc":"iex> Cldr.Rbnf.rule_names_for_locale \"zh\"\n    {:ok,\n     [:spellout_cardinal_alternate2, :spellout_ordinal, :spellout_cardinal,\n      :spellout_cardinal_financial, :spellout_numbering, :spellout_numbering_days,\n      :spellout_numbering_year, :digits_ordinal]}\n\n    iex> Cldr.Rbnf.rule_names_for_locale \"fp\"\n    {:error, {Cldr.InvalidLanguageError, \"The language \"fp\" is invalid\"}}","ref":"Cldr.Rbnf.html#rule_names_for_locale/1-examples"},{"type":"function","title":"Cldr.Rbnf.rule_names_for_locale/2","doc":"","ref":"Cldr.Rbnf.html#rule_names_for_locale/2"},{"type":"function","title":"Cldr.Rbnf.rule_names_for_locale!/1","doc":"Returns the list of RBNF rules for a locale.\n\nA rule name can be used as the `:format` parameter\nin `Cldr.Number.to_string/3`.","ref":"Cldr.Rbnf.html#rule_names_for_locale!/1"},{"type":"function","title":"Arguments - Cldr.Rbnf.rule_names_for_locale!/1","doc":"* `locale` is any `Cldr.LanguageTag.t()`","ref":"Cldr.Rbnf.html#rule_names_for_locale!/1-arguments"},{"type":"function","title":"Returns - Cldr.Rbnf.rule_names_for_locale!/1","doc":"* `[list_of_rule_names_as_atoms]`, or\n\n* raises an exception","ref":"Cldr.Rbnf.html#rule_names_for_locale!/1-returns"},{"type":"function","title":"Examples - Cldr.Rbnf.rule_names_for_locale!/1","doc":"iex> Cldr.Rbnf.rule_names_for_locale! \"zh\"\n    [:spellout_cardinal_alternate2, :spellout_ordinal, :spellout_cardinal,\n     :spellout_cardinal_financial, :spellout_numbering, :spellout_numbering_days,\n     :spellout_numbering_year, :digits_ordinal]","ref":"Cldr.Rbnf.html#rule_names_for_locale!/1-examples"},{"type":"module","title":"Cldr.Rbnf.Processor","doc":"Macro to define the interpreter for the compiled RBNF rules specific to a rule group (Ordinal,\nSpellout, NumberingSystem)","ref":"Cldr.Rbnf.Processor.html"},{"type":"function","title":"Cldr.Rbnf.Processor.define_rules/3","doc":"","ref":"Cldr.Rbnf.Processor.html#define_rules/3"},{"type":"function","title":"Cldr.Rbnf.Processor.rbnf_rule_error/3","doc":"","ref":"Cldr.Rbnf.Processor.html#rbnf_rule_error/3"},{"type":"module","title":"Cldr.Rbnf.Rule","doc":"Tokenizer and Parser for RBNF rules.","ref":"Cldr.Rbnf.Rule.html"},{"type":"function","title":"Cldr.Rbnf.Rule.parse/1","doc":"Parse an RBNF rule definition\n\nReturns a list of rule subparts that can then be used for\nfurther processing or for turning into an AST for execution.","ref":"Cldr.Rbnf.Rule.html#parse/1"},{"type":"function","title":"Cldr.Rbnf.Rule.tokenize/1","doc":"Scan and tokenize rule definition\n\nUsing a leex lexer, tokenize a rule definition","ref":"Cldr.Rbnf.Rule.html#tokenize/1"},{"type":"exception","title":"Cldr.CurrencyAlreadyDefined","doc":"Exception raised when an attempt is made to define a currency\nthat already exists.","ref":"Cldr.CurrencyAlreadyDefined.html"},{"type":"exception","title":"Cldr.CurrencyCodeInvalid","doc":"Exception raised when an attempt is made to define a currency\ncode that is invalid.","ref":"Cldr.CurrencyCodeInvalid.html"},{"type":"exception","title":"Cldr.NoNumberSymbols","doc":"Exception raised when when there are no number\nsymbols for a locale and number system.","ref":"Cldr.NoNumberSymbols.html"},{"type":"exception","title":"Cldr.Number.ParseError","doc":"Exception raised when when trying to parse\na string into a number and the string is\nnot parseable.","ref":"Cldr.Number.ParseError.html"},{"type":"exception","title":"Cldr.Rbnf.NoRule","doc":"Exception raised when an attempt is made to invoke an RBNF rule that\nis not supported for a given locale","ref":"Cldr.Rbnf.NoRule.html"},{"type":"exception","title":"Cldr.Rbnf.NoRuleForNumber","doc":"Exception raised when an attempt is made to invoke an RBNF rule for a number\nthat is not supported by that rule.","ref":"Cldr.Rbnf.NoRuleForNumber.html"},{"type":"extras","title":"Number and Currency Localization and Formatting","doc":"# Number and Currency Localization and Formatting\n\n![Build status](https://github.com/elixir-cldr/cldr_numbers/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_numbers.svg)](https://hex.pm/packages/ex_cldr_numbers)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_numbers.svg?)](https://hex.pm/packages/ex_cldr_numbers)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_cldr_numbers.svg?)](https://hex.pm/packages/ex_cldr_numbers)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_numbers.svg)](https://hex.pm/packages/ex_cldr_numbers)","ref":"readme.html"},{"type":"extras","title":"Introduction and Getting Started - Number and Currency Localization and Formatting","doc":"[ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers) is an addon library application for [ex_cldr](https://hex.pm/packages/ex_cldr) that provides localization and formatting for numbers and currencies.\n\nIn order to use this library, a backend module for `ex_cldr` must be defined.  This is described in full in the [ex_cldr readme](https://hexdocs.pm/ex_cldr/readme.html#configuration).  To get started, define a backend module in your project as follows:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [:en, :fr, :zh],\n    providers: [Cldr.Number]\nend\n```\n\nThe following examples assume the existence of this module.\n\nThe primary api is `MyApp.Cldr.Number.to_string/2`.  The following examples demonstrate:\n\n```elixir\niex> MyApp.Cldr.Number.to_string 12345\n{:ok, \"12,345\"}\n\niex> MyApp.Cldr.Number.to_string 12345, locale: :fr\n{:ok, \"12 345\"}\n\niex> MyApp.Cldr.Number.to_string 12345, locale: :fr, currency: \"USD\"\n{:ok, \"12 345,00 $US\"}\n\niex> MyApp.Cldr.Number.to_string 12345, locale: :en, currency: \"USD\", currency_symbol: :iso\n{:ok, \"USD 12,345.00\"}\n\niex> MyApp.Cldr.Number.to_string 12345, format: \"#E0\"\n{:ok, \"1.2345E4\"}\n```\n\nFor help in `iex`:\n\n```elixir\niex> h MyApp.Cldr.Number.to_string\n```","ref":"readme.html#introduction-and-getting-started"},{"type":"extras","title":"Known restrictions and limitations - Number and Currency Localization and Formatting","doc":"[Unicode technical report TR35](http://unicode.org/reports/tr35/tr35-numbers.html) states that for scientific formats (i.e. mantissa and exponent):\n\n> The maximum number of integer digits, if present, specifies the exponent grouping. The most common use of this is to generate engineering notation, in which the exponent is a multiple of three, for example, \"##0.###E0\". The number 12345 is formatted using \"##0.####E0\" as \"12.345E3\".\n\n`ex_cldr_numbers` does not currently support this functionality.","ref":"readme.html#known-restrictions-and-limitations"},{"type":"extras","title":"Installation - Number and Currency Localization and Formatting","doc":"Note that [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers) requires Elixir 1.10 or later.\n\nAdd `ex_cldr_numbers` as a dependency to your `mix` project:\n\n    defp deps do\n      [\n        {:ex_cldr_numbers, \"~> 2.33\"}\n      ]\n    end\n\nthen retrieve `ex_cldr_numbers` from [hex](https://hex.pm/packages/ex_cldr_numbers):\n\n    mix deps.get\n    mix deps.compile","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Number and Currency Localization and Formatting","doc":"`ex_cldr_numbers` uses the configuration set for the dependency `ex_cldr`.  See the documentation for [ex_cldr](https://hexdocs.pm/ex_cldr)","ref":"readme.html#configuration"},{"type":"extras","title":"Formatting Numbers - Number and Currency Localization and Formatting","doc":"CLDR defines many different ways to format a number for different uses and defines a set of formats categorised by common pupose to make it easier to express the same intent across many different locales that represent many different territories, cultures, number systems and scripts.\n\nSee `MyApp.Cldr.Number`, `MyApp.Cldr.Number.to_string/2` and `Cldr.Number.to_number_system/3`.","ref":"readme.html#formatting-numbers"},{"type":"extras","title":"Primary Public API - Number and Currency Localization and Formatting","doc":"The primary api for number formatting is `MyApp.Cldr.Number.to_string/2`.  It provides the ability to format numbers in a standard way for configured locales.  It also provides the means for format numbers as a currency, as a short form (like 1k instead of 1,000).  Additionally it provides formats to spell a number in words, format it as roman numerals and output an ordinal number.  Some examples illustrate:\n\n```elixir\niex> MyApp.Cldr.Number.to_string 12345\n{:ok, \"12,345\"}\n\niex> MyApp.Cldr.Number.to_string 12345, locale: :fr\n{:ok, \"12 345\"}\n\niex> MyApp.Cldr.Number.to_string 12345, locale: :fr, currency: \"USD\"\n{:ok, \"12 345,00 $US\"}\n\niex> MyApp.Cldr.Number.to_string 12345, format: \"#E0\"\n{:ok, \"1.2345E4\"}\n\niex> MyApp.Cldr.Number.to_string 12345, format: :accounting, currency: \"THB\"\n{:ok, \"THB12,345.00\"}\n\niex> MyApp.Cldr.Number.to_string -12345, format: :accounting, currency: \"THB\"\n{:ok, \"(THB12,345.00)\"}\n\niex> MyApp.Cldr.Number.to_string 12345, format: :accounting, currency: \"THB\", locale: :th\n{:ok, \"THB12,345.00\"}\n\niex> MyApp.Cldr.Number.to_string 12345, format: :accounting, currency: \"THB\", locale: :th, number_system: :native\n{:ok, \"THB๑๒,๓๔๕.๐๐\"}\n\niex> MyApp.Cldr.Number.to_string 12345, maximum_integer_digits: 2\n{:ok, \"45\"}\n\niex> MyApp.Cldr.Number.to_string 1244.30, format: :long\n{:ok, \"1 thousand\"}\n\niex> MyApp.Cldr.Number.to_string 1244.30, format: :long, currency: \"USD\"\n{:ok, \"1,244.30 US dollars\"}\n\niex> MyApp.Cldr.Number.to_string 1244.30, format: :short\n{:ok, \"1K\"}\n\niex> MyApp.Cldr.Number.to_string 1244.30, format: :short, currency: \"EUR\"\n{:ok, \"€1.24K\"}\n\niex> MyApp.Cldr.Number.to_string 1234, format: :spellout\n{:ok, \"one thousand two hundred thirty-four\"}\n\niex> MyApp.Cldr.Number.to_string 1234, format: :spellout_verbose\n{:ok, \"one thousand two hundred and thirty-four\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :ordinal\n{:ok, \"123rd\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :roman\n{:ok, \"CXXIII\"}\n\niex> MyApp.Number.to_string 123, locale: \"th-u-nu-thai\"\n{:ok, \"๑๒๓\"}\n\niex> MyApp.Number.to_string 123, format: :currency, locale: \"en-u-cu-thb\"\n{:ok, \"THB 123.00\"}\n```","ref":"readme.html#primary-public-api"},{"type":"extras","title":"Standard Formatting Styles - Number and Currency Localization and Formatting","doc":"`Cldr` supports the styles of formatting defined by CLDR being:\n\n*  `:standard` which formats a number if a decimal format commonly used in many locales.  This is the default format.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 1234, format: :standard\n{:ok, \"1,234\"}\n```\n\n*  `:currency` which formats a number according to the format or a particular currency adjusted for rounding, number of decimal digits after the fraction, whether the currency is accounting or cash rounded and using the appropriate locale-specific currency symbol.  This format also requires that the option `:currency` be specified.  Note that for currency formatting the defined rounding and fractional digits defined for the currency is used.  The parameter `:currency_digits` can also be specified to indicate if formatting is to use `:accounting`, `:cash` or `:iso` digit definitions.  The default is `:accounting`. Some currencies, like the Swiss Franc and Australian Dollar have a smallest cash amount that is 0.05 of the Franc of Dollar and hence rounding has to take that into account.  When a currency format is requested, the option `:currency_symbol` may also be set to `:iso`. In this case the ISO currency code will be used instead of the currency symbol.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 1234.31, format: :currency, currency: :CHF\n{:ok, \"CHF1,234.31\"}\n\niex> MyApp.Cldr.Number.to_string 1234.31, format: :currency, currency: :CHF, currency_digits: :cash\n{:ok, \"CHF1,234.30\"}\n```\n\n*  `:accounting` which formats a positive number like `:standard` but which usually wraps a negative number in `()`. The `:accounting` format also requires that the `:currency` option be specified.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 1234, format: :accounting, currency: :THB\n{:ok, \"THB1,234.00\"}\n\niex> MyApp.Cldr.Number.to_string -1234, format: :accounting, currency: :THB\n{:ok, \"(THB1,234.00)\"}\n```\n\n*  `:percent` which multiplies a number by 100 and includes a locale-specific percent symbol which is usually `%`.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 0.09, format: :percent\n{:ok, \"9%\"}\n```\n\n*  `:permille` (aka 'basis points') which multiples a number by 1,000 and includes a locale specific permille symbol which is usually `‰`. Note that many (most?) locales don't provide a `:permille` format definition.  The alternative is to specify a format string as in the example below.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 0.56, format: \"#‰\"\n{:ok, \"560‰\"}\n\niex> MyApp.Cldr.Number.to_string 0.56, format: :permille\n{:error,\n {MyApp.Cldr.UnknownFormatError,\n  \"The locale \\\"en\\\" with number system :default does not define a format :permille.\"}}\n```\n\n*  `:scientific` which formats a number as a mantissa and base-10 exponent.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 124.56, format: :scientific\n{:ok, \"1.2456E2\"}\n```\n\nSee `MyApp.Cldr.Number.Formatter.Decimal`.","ref":"readme.html#standard-formatting-styles"},{"type":"extras","title":"Short and Long Formats - Number and Currency Localization and Formatting","doc":"`Cldr` also supports formats that minimise publishing space or which attempt to make large numbers more human-readable.\n\n* `:short` which presents a number or currency in a narrow space.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 12456.56, format: :short\n{:ok, \"12K\"}\n\niex> MyApp.Cldr.Number.to_string 12456.56, format: :short, currency: :USD\n{:ok, \"$12K\"}\n```\n\n* `:long` which presents numbers in a sentence form adjusted for plurality and locale.  For example, `1,0000` would be formatted as `1 thousand`.  This is not the same as spelling out the number which is part of the Unicode CLDR Rules-Based Number Formatting.  See `MyApp.Cldr.Rbnf`.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 12456.56, format: :long\n{:ok, \"12 thousand\"}\n\niex> MyApp.Cldr.Number.to_string 1, format: :long, currency: :USD\n{:ok, \"1 US dollar\"}\n\niex> MyApp.Cldr.Number.to_string 12456.56, format: :long, currency: :USD\n{:ok, \"12,457 US dollars\"}\n```\n\nSee `MyApp.Cldr.Number.Formatter.Short` and `MyApp.Cldr.Number.Formatter.Currency`.","ref":"readme.html#short-and-long-formats"},{"type":"extras","title":"Locale extensions affecting formatting - Number and Currency Localization and Formatting","doc":"A locale identifier can specify options that affect number formatting. These options are:\n\n* `cu`: defines the currency to be used when `currency: :from_locale` is specified.\n\n* `cf`: defines whether to use currency or accounting format for formatting currencies when no `:format` is specified but a `:currency` is specified. In the case where the backend configuration sets the `:default_currency_format` to either `:currency` or `:accounting` that format overrides the format specified in the locale.\n\n* `nu`: defines the number system to be used if no `:number_system` option to `to_string/2` is provided.\n\nThese keys are part of the [u extension](https://unicode.org/reports/tr35/#u_Extension) and\nthat document should be consulted for details on how to construct a locale identifier with these\nextensions. The following examples illustrate:\n```\n# No :format is specified but a currency is. The format (:currency or\n# :accounting) is derived from the locale. Whenever a\n# :currency option is specified it forces a format of either\n# :currency or :accounting.\niex> MyApp.Cldr.Number.to_string 123, locale: \"th-u-nu-thai\", currency: :from_locale\n{:ok, \"฿๑๒๓.๐๐\"}\n\n# A :format is specified and takes precedence over the format\n# implied by the locale. The currency itself is derived from the\n# locale.\niex> MyApp.Cldr.Number.to_string 123, format: :currency, locale: \"en-u-cu-thb\", currency: :from_locale\n{:ok, \"THB 123.00\"}\n```","ref":"readme.html#locale-extensions-affecting-formatting"},{"type":"extras","title":"User-Specified Number Formats - Number and Currency Localization and Formatting","doc":"User-defined decimal formats are also supported using the formats described by\n[Unicode technical report TR35](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Format_Patterns).\n\nThe formats described therein are supported by `ex_cldr_numbers` with some minor omissions and variations.  Some examples of number formats are:\n\n  | Pattern       | Currency        | Text        |\n  | ------------- | :-------------: | ----------: |\n  | #,##0.##      | n/a\t            | 1 234,57    |\n  | #,##0.###     | n/a\t            | 1 234,567   |\n  | ###0.#####    | n/a\t            | 1234,567    |\n  | ###0.0000#    | n/a\t            | 1234,5670   |\n  | 00000.0000    | n/a\t            | 01234,5670  |\n  | 00            | n/a             | 12          |\n  | #,##0.00 ¤    | EUR\t            | 1 234,57 €  |\n\n See `MyApp.Cldr.Number` and `MyApp.Cldr.Number.Formatter.Decimal`.","ref":"readme.html#user-specified-number-formats"},{"type":"extras","title":"Number Pattern Character Definitions - Number and Currency Localization and Formatting","doc":"The following table describes the symbols used in a number format string and is extracted from [TR35](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Format_Patterns)\n\n  | Symbol | Location   | Localized Replacement | Meaning                                          |\n  | :----: | ---------- | --------------------- |------------------------------------------------- |\n  | 0      | Number     | digit                 | Digit                                            |\n  | 1 .. 9 | Number     | digit                 | '1' through '9' indicate rounding                |\n  | @      | Number     | digit                 | Significant digit                                |\n  | #      | Number     | digit, *nothing*      | Digit, omit leading/trailing zeros               |\n  | .      | Number     | decimal symbol        | Decimal or monetary decimal separator            |\n  | -      | Number     | minus sign            | Minus sign [1]                          |\n  | ,      | Number     | grouping separator    | Decimal/monetary grouping separator [2] [3]                     |\n  | *      | Pre/Suffix | padding character     | Pad escape, precedes padding character           |\n  | '      | Pre/Suffix | syntax only           | To quote special chars.  eg '#'                  |","ref":"readme.html#number-pattern-character-definitions"},{"type":"extras","title":"Notes - Number and Currency Localization and Formatting","doc":"[1]  The pattern `'-'0.0` is not the same as the pattern `-0.0`. In the former case, the minus sign is a literal. In the latter case, it is a special symbol, which is replaced by the localised minus symbol, and can also be replaced by the plus symbol for a format like +12%.\n\n   [2]  May occur in both the integer part and the fractional part. The position determines the grouping.\n\n   [3]  Any sequence is replaced by the localized currency symbol for the currency being formatted, as in the table below. If present in a pattern, the monetary decimal separator and grouping separators (if available) are used instead of the numeric ones. If data is unavailable for a given sequence in a given locale, the display may fall back to `¤` or `¤¤`.\n\n  | No.  | Replacement Example                                                   |\n  | ---- | --------------------------------------------------------------------- |\n  | ¤    | Standard currency symbol as in `C$12.00`                              |\n  | ¤¤   | ISO currency symbol as in `CAD 12.00`                                 |\n  | ¤¤¤  | Appropriate currency display name based upon locale and plural rules  |\n  | ¤¤¤¤ | Narrow currency symbol as in `$12.00`                                 |","ref":"readme.html#notes"},{"type":"extras","title":"Rule Based Number Formats - Number and Currency Localization and Formatting","doc":"CLDR provides an additional mechanism for the formatting of numbers.  This approach can be used to format numbers in locale-specific words, or to format numbers in a number system that does not use the decimal digits `0` through `9` such as Chinese and Hebrew.\n\n#### Formatting numbers as words, ordinals and roman numerals\n\n* As words.  For example, formatting 123 into \"one hundred and twenty-three\" for the :en locale.  The applicable format types are `:spellout` and `:spellout_verbose`.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 123, format: :spellout\n{:ok, \"one hundred twenty-three\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :spellout_verbose\n{:ok, \"one hundred and twenty-three\"}\n```\n\n* As a year. In many languages the written form of a year is different to that used for an arbitrary number.  For example, formatting 1989 would result in \"nineteen eighty-nine\".  The applicable format type is `:spellout_year`.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 2017, format: :spellout_year\n{:ok, \"twenty seventeen\"}\n```\n\n* As an ordinal. For example, formatting 123 into \"123rd\".  The applicable format types are `:ordinal`, `:spellout_ordinal` and `:spellout_ordinal_verbose`.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 123, format: :ordinal\n{:ok, \"123rd\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :spellout_ordinal\n{:ok, \"one hundred twenty-third\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :spellout_ordinal_verbose\n{:ok, \"one hundred and twenty-third\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :ordinal, locale: :fr\n{:ok, \"123e\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :ordinal, locale: :zh\n{:ok, \"第123\"}\n```\n\n* As Roman numerals. For example, formatting 123 into \"CXXIII\".  The applicable formats are `:roman` or `:roman_lower`.  Note that roman number formatting is only supported for numbers between 1 and 5,000.\n\n```elixir\niex> MyApp.Cldr.Number.to_string 123, format: :roman\n{:ok, \"CXXIII\"}\n\niex> MyApp.Cldr.Number.to_string 123, format: :roman_lower\n{:ok, \"cxxiii\"}\n\niex> MyApp.Cldr.Number.to_string 12345, format: :roman_lower\n{:ok, \"12,345\"}\n```\n\n#### Converting numbers to non-latin number systems\n\nSome number systems, such as Hebrew and Chinese, do not use the digits 0 through 9 in the their native number system.  RBNF defines rules for these and other number systems that can provide number system conversion.  `MyApp.Cldr.Number.to_string/2` does not support number systems without digits defined therefore another mechanism is required to output numbers in these algorithmic number systems.  To support number system conversion, the function `Cldr.Number.to_number_system/3` is provided.  Note that no formatting is supported, this is a number system conversion only.\n\nFor example, to output a number in the `:hans` numbering system (Chinese) and the Hebrew number system:\n\n```elixir\niex> Cldr.Number.to_number_system 123, :hans, MyApp.Cldr\n{:ok, \"一百二十三\"}\n\niex> Cldr.Number.to_number_system 123, :hebr, MyApp.Cldr\n{:ok, \"ק׳\"}\n```\n\n`Cldr.Number.to_number_system/3` supports the conversion between numeric number systems (those with digits 0 through 9) in addition to algorithmic number systems (those supported by rules-based number formatting).  For example, outputting to the `:thai` number system:\n\n```elixir\niex> Cldr.Number.to_number_system 123, :thai, MyApp.Cldr\n{:ok, \"๑๒๓\"}\n```\n\nThe known number systems in `Cldr` can be returned by the function `Cldr.Number.System.known_number_systems/0`:\n\n```elixir\niex> Cldr.Number.System.known_number_systems\n[:adlm, :ahom, :arab, :arabext, :armn, :armnlow, :bali, :beng, :bhks, :brah,\n :cakm, :cham, :cyrl, :deva, :ethi, :fullwide, :geor, :grek, :greklow, :gujr,\n :guru, :hanidays, :hanidec, :hans, :hansfin, :hant, :hantfin, :hebr, :hmng,\n :java, :jpan, :jpanfin, :kali, :khmr, :knda, :lana, :lanatham, :laoo, :latn,\n :lepc, :limb, :mathbold, :mathdbl, :mathmono, :mathsanb, :mathsans, :mlym,\n :modi, :mong, :mroo, ...]\n```\n\n#### RBNF rules defined in CLDR\n\nThere are also many additional methods more specialised to a specific locale that cater for languages with more complex gender and grammar requirements.  Since these rules are specialised to a locale it is not possible to standarise the public API more than described in this section.\n\nThe full set of RBNF formats is accessible through the modules `MyApp.Cldr.Rbnf.Ordinal`, `MyApp.Cldr.Rbnf.Spellout` and `MyApp.Cldr.Rbnf.NumberSystem`.\n\nEach of these modules has a set of functions that are generated at compile time that implement the relevant RBNF rules.  The available rules for a given locale can be retrieved by calling `MyApp.Cldr.Rbnf.Spellout.rule_set(locale)` or the same function on the other modules.  For example:\n\n    iex> MyApp.Cldr.Rbnf.Ordinal.rule_sets :en\n    [:digits_ordinal]\n\n    iex> MyApp.Cldr.Rbnf.Spellout.rule_sets :fr\n    [:spellout_ordinal_masculine_plural, :spellout_ordinal_masculine,\n     :spellout_ordinal_feminine_plural, :spellout_ordinal_feminine,\n     :spellout_numbering_year, :spellout_numbering, :spellout_cardinal_masculine,\n     :spellout_cardinal_feminine]\n\nThese rule-based formats are invoked directly on the required module passing the number and locale.  For example:\n\n```elixir\niex> MyApp.Cldr.Rbnf.Spellout.spellout_numbering_year 1989, :fr\n\"dix-neuf-cent quatre-vingt-neuf\"\n\niex> MyApp.Cldr.Rbnf.Spellout.spellout_numbering_year 1989, :en\n\"nineteen eighty-nine\"\n\niex> MyApp.Cldr.Rbnf.Ordinal.digits_ordinal 1989, :en\n\"1,989th\"\n```\n\n#### RBNF Rules with Float numbers\n\nRBNF is primarily oriented towards positive integer numbers.  Whilst the standard caters for negative numbers and fractional numbers the implementation of the rules is incomplete.  Use with care.","ref":"readme.html#rule-based-number-formats"},{"type":"extras","title":"Parsing Numbers from a string - Number and Currency Localization and Formatting","doc":"`Cldr.Number.Parser` provides two functions to support the parsing of localised number strings into numbers.  `Cldr.Number.Parser.parse/2` assumes the string is a number only. `Cldr.Number.Parser.scan/2` will attempt to extract numbers from an arbitrary string.\n\nIn all cases, the locale-specific number separators are permitted providing a reliable way to extract locale-specific numbers from a string.","ref":"readme.html#parsing-numbers-from-a-string"},{"type":"extras","title":"Examples - Number and Currency Localization and Formatting","doc":"iex> Cldr.Number.Parser.parse(\"＋1.000,34\", locale: :de)\n    {:ok, 1000.34}\n\n    iex> Cldr.Number.Parser.parse(\"-1_000_000.34\")\n    {:ok, -1000000.34}\n\n    iex> Cldr.Number.Parser.parse(\"1.000\", locale: :de, number: :integer)\n    {:ok, 1000}\n\n    iex> Cldr.Number.Parser.parse(\"＋1.000,34\", locale: :de, number: :integer)\n    {:error, \"＋1.000,34\"}\n\n    iex> Cldr.Number.Parser.scan(\"£1_000_000.34\")\n    [\"£\", 1000000.34]\n\n    iex> Cldr.Number.Parser.scan(\"I want £1_000_000 dollars\")\n    [\"I want £\", 1000000, \" dollars\"]\n\n    iex> Cldr.Number.Parser.scan(\"The prize is 23\")\n    [\"The prize is \", 23]\n\n    iex> Cldr.Number.Parser.scan(\"The lottery number is 23 for the next draw\")\n    [\"The lottery number is \", 23, \" for the next draw\"]\n\n    iex> Cldr.Number.Parser.scan(\"The loss is -1.000 euros\", locale: :de, number: :integer)\n    [\"The loss is \", -1000, \" euros\"]","ref":"readme.html#examples"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr Numbers v2.33.4 - Changelog","doc":"This is the changelog for Cldr v2.33.4 released on November 13th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-33-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes unquoting invalid AST on the upcoming Elixir 1.18. Thanks very much to @sabiwara for the [PR](https://github.com/elixir-cldr/cldr_numbers/pull/52). Thanks too to @SteffenDE for the report. Closes #53.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.33.3 - Changelog","doc":"This is the changelog for Cldr v2.33.3 released on August 16th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-33-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix specs to suport dialyzer flags `:error_handling, :unknown, :underspecs, :extra_return, :missing_return`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.33.2 - Changelog","doc":"This is the changelog for Cldr v2.33.2 released on July 30th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-33-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec for `all_formats_for!/3`. Thanks to @@AntoineAugusti for the report. Closes #50.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.33.1 - Changelog","doc":"This is the changelog for Cldr v2.33.1 released on April 23rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-33-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add `config/prod.exs` so `MIX_ENV=prod` compilation succeeds. Thanks to @camelpunch for the report. Closes #49.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.33.0 - Changelog","doc":"This is the changelog for Cldr v2.33.0 released on April 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-33-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 45.0](https://cldr.unicode.org/index/downloads/cldr-45) data.\n\n* Support currency formatting when the given currency in a given locale uses a specific symbol that replaces the decimal separator. The only known example is the [Cape Verde escudo](https://en.wikipedia.org/wiki/Cape_Verdean_escudo). A formatted example formatting 20 CVE is `20$00`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Numbers v2.32.4 - Changelog","doc":"This is the changelog for Cldr v2.32.4 released on January 18th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-32-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting a number when a currency is specified but the format has no currency symbol. Closes [ex_money 162](https://github.com/kipcole9/money/issues/162).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.32.3 - Changelog","doc":"This is the changelog for Cldr v2.32.3 released on November 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)\n\n* Fix formatting a number when a currency is specified but the format has no currency symbol. Closes [ex_money 162](https://github.com/kipcole9/money/issues/162).","ref":"changelog.html#cldr-numbers-v2-32-3"},{"type":"extras","title":"Cldr Numbers v2.32.3 - Changelog","doc":"This is the changelog for Cldr v2.32.0 released on November 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-32-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compiler warnings on Elixir 1.16.\n\n* Fix return spec for `Cldr.Number.to_string/2`. Thanks to @Munksgaard for the PR. Closes #45.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.32.2 - Changelog","doc":"This is the changelog for Cldr v2.32.0 released on September 12th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-32-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes RBNF rules for fractions. Previous the rule `:spellout_cardinal` was being used to format the fractional part of a number. However this rule is not defined for many locales. This is changed to `:spellout_numbering` which is available in all known locales.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.32.1 - Changelog","doc":"This is the changelog for Cldr v2.32.0 released on September 9th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-32-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use currency default fractional digits for currency formats if no `:fractional_digits` option is provided. Thanks to @dhedlund  for the report.  This reverts that change made in 2.31.3 which was described as \"Don't override currency fractional digits when formatting a number. The format should always define the fractional digits unless overriden by the `:fractional_digits` option.\" Fractional digits will also be set to the currency definition of digits unless overriden.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.32.0 - Changelog","doc":"This is the changelog for Cldr v2.32.0 released on September 4th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-32-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix formatting numbers with format `:standard` when the standard format is an RBNF rule.\n\n* Fix formatting numbers with an RBNF format that is defined on locale `:und` even when the formatting locale doesn't have an `:rbnf_locale_name`.\n\n* Improve several error messages around number systems and RBNF rules.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Deprecations - Changelog","doc":"* `Cldr.Number.System.systems_with_digits/0` is deprecated in favour of `Cldr.Number.System.numeric_systems/0`.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Number.System.algorithmic_systems/0` which is the counterpoint to `Cldr.Number.System.numeric_systems/0`.\n\n* Functions in the `Cldr.Number.Format` module now default the `backend` argument to be `Cldr.default_backend!/0`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Numbers v2.31.3 - Changelog","doc":"This is the changelog for Cldr v2.31.3 released on July 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-31-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Support `format: :scientific` which is documented but was not implemented as a valid option.  Thanks to @petrus-jvrensburg for the report. Closes #38.\n\n* Don't override currency fractional digits when formatting a number. The format should always define the fractional digits unless overriden by the `:fractional_digits` option.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.31.2 - Changelog","doc":"This is the changelog for Cldr v2.31.2 released on July 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-31-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes formatting of numbers in locales where the locale has no RBNF. Thanks to @petrus-jvrensburg for the report. Closes #37.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.31.1 - Changelog","doc":"This is the changelog for Cldr v2.31.1 released on May 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-31-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Ensure all RBNF rule names are valid function names. In at least one case (\"2d_year\") a rule name does not map to a valid Elixir function name.  The rules are built with atom function names which is valid, but the string versions of that name do not parse. `MyApp.Cldr.Rbnf.Spellout.2d_year/2` does not parse, evening though the function exists. This can cause interoperabiity issues with other libraries the introspect code, like `inch_ex`.  From this release, rule names are forced to be valid, parseable function names by prepending an \"r\" to the rule name if the rule name starts with a digit. Thanks to @ggarciajr for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.31.0 - Changelog","doc":"This is the changelog for Cldr v2.31.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-31-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.37.0](https://hex.pm/packages/ex_cldr/2.37.0) which includes data from [CLDR release 43](https://cldr.unicode.org/index/downloads/cldr-43)\n\n* Support a `:wrapper` function to return `iodata` when used as an option to `Cldr.Number.to_string/2`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Numbers v2.30.1 - Changelog","doc":"This is the changelog for Cldr v2.30.1 released on March 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-30-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes currency formats where the currency symbol is neither the first or last token. Thanks to @simoncocking for the issue. Closes #35.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Numbers v2.30.0 - Changelog","doc":"This is the changelog for Cldr v2.30.0 released on March 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr-numbers-v2-30-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix short formatting for decimal numbers. Thanks to @dbernheisel for the report. Closes #34.\n\n* Fix formatting negative numbers when the currency symbol results in an alphabetic character next to the number. In these cases a special format `:currency_alpha_next_to_number` (or `:accounting_alpha_next_to_number`) is used. These formats are only available in CLDR42 or later and therefore `ex_cldr` version 2.35.0 or later is required.\n\n* Specifies Elixir 1.11 or later in alignment with the requirements for `ex_cldr`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Supports the `:default_currency_format` backend configuration option introduced in `ex_cldr` version 2.35.0.\n\n* Adds `:from_locale` as a valid value to the `:currency` option to `Cldr.Number.to_string/3`. If set, the currency is derived from the locale.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.29.0 - Changelog","doc":"This is the changelog for Cldr v2.29.0 released on January 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-29-0"},{"type":"extras","title":"Behavior change - Changelog","doc":"* In prior releases formatting a number as `format: :currency` would derive the currency code from the locale if no `:currency` was provided.  This is no longer the case.  As of CLDR42 a format `:currency_no_symbol` is defined to allow formatting of the number without an associated symbol.  Now when `format: :currency` is passed without a `:currency` option, the format is changed to `format: :currency_no_symbol`. To retain the existing behaviour, pass `currency: Cldr.Currency.currency_from_locale(locale)` as an option.\n\n* In prior releases the currency format (:currency or :accounting) would be overriden by any choice expressed in the locale. That is no longer the case from this release. To retain the existing behaviour, pass `format: Cldr.Currency.currency_format_from_locale(locale)` as an option.","ref":"changelog.html#behavior-change"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds an option `:wrapper` to `Cldr.Number.to_string/2`. The argument is a 2-arity function that receives the parameters `string` and `tag` where `tag` is one of `:number`, `:currency_symbol`, `:currency_space`, `:literal`, `:quote`, `:percent`, `:permille`, `:minus` or `:plus`. The function must return a string or a \"safe string\" such as that returned by `Phoenix.HTML.Tag.content_tag/3`. The function can be used to wrap format elements in HTML or other tags.  Thanks to @rubas for the motivation and review. Example:\n```elixir\niex> Cldr.Number.to_string(100, format: :currency, currency: :USD, wrapper: fn\n...>   string, :currency_symbol -> \" \" <> string <> \" \"\n...>   string, :number -> \" \" <> string <> \" \"\n...>   string, :currency_space -> \" \" <> string <> \" \"\n...>   string, _other -> string\n...> end)\n{:ok, \" $  100.00 \"}\n\n# It is also possible and recommended to use the `Phoenix.HTML.Tag.content_tag/3`\n# function if wrapping HTML tags since these will ensure HTML entities are\n# correctly encoded.  For example:\niex> Cldr.Number.to_string(100, format: :currency, currency: :USD, wrapper: fn\n...>   string, :currency_symbol -> Phoenix.HTML.Tag.content_tag(:span, string, class: \"symbol\")\n...>   string, :number -> Phoenix.HTML.Tag.content_tag(:span, string, class: \"number\")\n...>   string, :currency_space -> Phoenix.HTML.Tag.content_tag(:span, string)\n...>   string, _other -> string\n...> end)\n{:ok, \" $  100.00 \"}\n```\n\n* Adds the number formats `:currency_no_symbol` and `:accounting_no_symbol` that can be used to format currency amounts without an associated currency symbol.\n\n* Removes the `Cldr.Number.to_string/3` requirement for a currency to be provided (or derived) when the format is `:currency`. If a currency is provided, the format `:currency` is used. If a currency is not provided, the format `:currency_no_symbol` is used.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.28.0 - Changelog","doc":"This is the changelog for Cldr v2.28.0 released on October 24th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-28-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Encapsulates [CLDR 42](https://cldr.unicode.org/index/downloads/cldr-42) data. Unless otherwise noted, all the changes are reflected in `ex_cldr` libraries and functions.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.27.3 - Changelog","doc":"This is the changelog for Cldr v2.27.3 released on October 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-27-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.Number.to_string/3` with `format: :narrow` and `:currency` set will use the currency's narrow symbol.\n\n* Apply currency spacing for short formats (previously not being applied)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.27.2 - Changelog","doc":"This is the changelog for Cldr v2.27.2 released on July 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-27-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `:short` formatting of decimal numbers with specified fractional digits. Thanks to @glennr for the report. Closes #32.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.27.1 - Changelog","doc":"This is the changelog for Cldr v2.27.1 released on July 20th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-27-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `:short` formatting of negative numbers. Thanks to @glennr for the report. Closes #30.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.27.0 - Changelog","doc":"This is the changelog for Cldr v2.27.0 released on May 14th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-27-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for formatting numbers representing [ISO 24165](https://www.iso.org/standard/80601.html) Digital Tokens (aka crypto currencies). The behaviour follows that for currency formatting. Given that the [digital token registry](https://dtif.org) does not contain fraction precision data or pluralised or localised token names, the formatting of digital tokens amounts is not localized beyond formatting the number itself.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.26.0 - Changelog","doc":"This is the changelog for Cldr v2.26.0 released on April 6th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-26-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update [CLDR](https://cldr.unicode.org) to [release 41](https://cldr.unicode.org/index/downloads/cldr-41) in [ex_cldr version 2.28.0](https://hex.pm/packages/ex_cldr/2.28.0)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.25.2 - Changelog","doc":"This is the changelog for Cldr v2.25.1 released on March 2nd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-25-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes formatting of `Decimal` `Inf` and `NaN` numbers. Thanks to @sh41 for the report. Closes #26.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.25.1 - Changelog","doc":"This is the changelog for Cldr v2.25.1 released on February 22nd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-25-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove compiler warnings on Elixir 1.11. Thanks to @koszta for the report. Fixes #24.\n\n* Remove spurious `@dialyzer` directives that are no longer required (because we understand dialyzer a little bit more now).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.25.0 - Changelog","doc":"This is the changelog for Cldr v2.25.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-25-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) which uses atoms for locale names and rbnf locale names. This is consistent with out elements of `t:Cldr.LanguageTag` where atoms are used where the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.24.0 - Changelog","doc":"This is the changelog for Cldr v2.24.0 released on December 30th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-24-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Allowed limited forms of format composition. For example, composing a `:long` format with a `:currency` format:\n```elixir\niex> Cldr.Number.to_string!(100_000_000, format: :long) |> Cldr.Number.to_string(format: :currency)\n{:ok, \"$100 million\"}\n```\n\n* Add format `:currency_long_with_symbol` which is a composite of `:currency_long` and the locales standard currency format. This supports formatting of of numbers like \"$100 million\" in the example above.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.23.3 - Changelog","doc":"This is the changelog for Cldr v2.23.3 released on December 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes short formatting for decimal numbers. Thanks to @datrader for the report.  Closes #135 on [ex_money](https://github.com/kipcole9/ex_money).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.23.2 - Changelog","doc":"This is the changelog for Cldr v2.23.2 released on December 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `Cldr.Number.Parser.resolve_currencies/1` when the argument is whitespace only. Thanks to @datrader for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.23.1 - Changelog","doc":"This is the changelog for Cldr v2.23.1 released on December 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Replace `use Mix.Config` with `import Config` in config files\n\n* Fix typespec for ` .Cldr.Number.Transliterate.transliterate_digits/3`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.23.0 - Changelog","doc":"This is the changelog for Cldr v2.23.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)\n\n* Adds `Cldr.Rbnf.rule_names_for_locale/1` to return the available RBNF rule names for a given locale.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Arbitrary RBNF rule lookup falls back to the root locale (called \"und\") when checking if a rule is available. Thanks to @maennchen for the report. Closes #22.\n\n* Fixes performance issue when calling `Cldr.Number.to_string/3` with an arbitrary RBNF rule name. Previously these formats would mistakenly read the raw json file for a locale incurring a significant performance penaly. Performance is now 100x faster as expected. Thanks to @maennchen for the bug report. Closes #21.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.\n\n* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_locale/2` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Numbers v2.23.0-rc.4 - Changelog","doc":"This is the changelog for Cldr v2.23.0-rc.4 released on October 26th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-0-rc-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Arbitrary RBNF rule lookup falls back to the root locale (called \"und\") when checking if a rule is available. Thanks to @maennchen for the report. Closes #22.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.23.0-rc.3 - Changelog","doc":"This is the changelog for Cldr v2.23.0-rc.3 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-0-rc-3"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Numbers v2.23.0-rc.2 - Changelog","doc":"This is the changelog for Cldr v2.23.0-rc.2 released on October 24th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-0-rc-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_locale/2` instead.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.23.0-rc.1 - Changelog","doc":"This is the changelog for Cldr v2.23.0-rc.1 released on October 24th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-0-rc-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Rbnf.rule_names_for_locale/1` to return the available RBNF rule names for a given locale.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes performance issue when calling `Cldr.Number.to_string/3` with an arbitrary RBNF rule name. Previously these formats would mistakenly read the raw json file for a locale incurring a significant performance penaly. Performance is now 100x faster as expected. Thanks to @maennchen for the bug report. Closes #21.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.23.0-rc.0 - Changelog","doc":"This is the changelog for Cldr v2.23.0-rc.0 released on October 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-23-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.22.1 - Changelog","doc":"This is the changelog for Cldr v2.22.1 released on September 13th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-22-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Return the remainder strings with casing preserved when resolving currencies and pers in `Cldr.Numbers.Parser`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.22.0 - Changelog","doc":"This is the changelog for Cldr v2.22.0 released on August 22nd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-22-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* `Cldr.Number.Parser.resolve_currencies/2` and `Cldr.Number.Parser.resolve_per/2` only perform replacements if the the found string is not adjacent to an alphabetic character.\n\n* `Cldr.Number.Parser.resolve/2` and `Cldr.Number.Parser.find_and_replace/2` are made public functions.\n\n* Add `resolve_pers/2` and `resolve_per/2` to the `MyApp.Number` module.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.21.0 - Changelog","doc":"This is the changelog for Cldr v2.21.0 released on August 18th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-21-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Number.Parser.resolve_pers/2` which will tokenize percent and permille symbols into `:percent` and `:permille`. This is similar to the `Cldr.Number.Parser.resolve_currencies/2` function but for percent and permille symbols. An example is:\n\n```elixir\niex> Cldr.Number.Parser.scan(\"100%\")\n...> |> Cldr.Number.Parser.resolve_pers()\n[100, :percent]\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.20.0 - Changelog","doc":"This is the changelog for Cldr v2.20.0 released on August 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-20-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Improve number parsing with `Cldr.Number.Parser.scan/2` when the string has lists of numbers separated by commas.  Thanks to @DaTrader for the report. Closes #19.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for custom currency symbols. This extends the use of the `:currency_symbol` option. In previously releases this option was required to be `:standard` or `:iso`. Now the value can also be `:narrow`, `:symbol` or a string which will be used as the currency symbol.  From the documentation for `Cldr.Number.to_string/3`:\n\n  * `currency_symbol`: Allows overriding a currency symbol. The alternatives\n    are:\n    * `:iso` the ISO currency code will be used instead of the default\n      currency symbol.\n    * `:narrow` uses the narrow symbol defined for the locale. The same\n      narrow symbol can be defined for more than one currency and therefore this\n      should be used with care. If no narrow symbol is defined, the standard\n      symbol is used.\n    * `:symbol` uses the standard symbol defined in CLDR. A symbol is unique\n      for each currency and can be safely used.\n    * \"string\" uses `string` as the currency symbol\n    * `:standard` (the default and recommended) uses the CLDR-defined symbol\n      based upon the currency format for the locale.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.19.0 - Changelog","doc":"This is the changelog for Cldr v2.19.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-19-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to [ex_cldr version 2.23.0](https://hex.pm/packages/ex_cldr/2.23.0) which changes the names of some of the field in the \"-u-\" extension to match the CLDR canonical name. In particular the field name `number_system` changes to `numbers`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.18.4 - Changelog","doc":"This is the changelog for Cldr v2.18.4 released on June 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-18-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Allow `t:Cldr.Currency` as a `:currency` option in `Cldr.Number.to_string/2`. Thanks to @jeroenvisser101 for the PR.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.18.3 - Changelog","doc":"This is the changelog for Cldr v2.18.3 released on June 12th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-18-3"},{"type":"extras","title":"Breaking Change - Changelog","doc":"* There is a minor breaking change in the error return from `Cldr.Number.Parser.parse/2`. Previously the error return was `{:error, string}`. It is now more consistent with the rest of `ex_cldr` and returns `{:error, {exception, message}}`","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Number.Parser.parse/2` for numbers that are in non-latin scripts (like Thai, Arabic, ...). There are 66 known number systems that have decimal digits as of CLDR39.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.18.2 - Changelog","doc":"This is the changelog for Cldr v2.18.2 released on June 11th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-18-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Number.Parser.scan/2` to correctly parse numbers like `1kg`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.18.1 - Changelog","doc":"This is the changelog for Cldr v2.18.1 released on June 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-18-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"Thanks to @alaadahmed for the collaboration to fix two bugs in rules based number formatting.\n\n* Fixes RBNF formatting options setting for `:spellout_ordinal`\n\n* Allows any defined RNBF rule for a locale to be invoked as the `:format` option to `Cldr.Number.to_string/3`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.18.0 - Changelog","doc":"This is the changelog for Cldr v2.18.0 released on May 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-18-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes short and long number formatting.\n\n* Fixes formatting whent the format string consists only of digits. Previously this would erroneously set both the maximum and minimum integer digits. Now it only sets the minimum integer digits.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add option `:maximum_integer_digits` as an option to `Cldr.Number.to_string/2`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.17.0 - Changelog","doc":"This is the changelog for Cldr v2.17.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-17-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to require [ex_cldr version 2.20](https://hex.pm/packages/ex_cldr/2.20.0) which includes [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39) data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.16.1 - Changelog","doc":"This is the changelog for Cldr v2.16.1 released on November 8th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-16-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix bug in `Cldr.Number.System.number_system_from/1` to correctly allow a binary language tag without a backend parameter (which will then default to `Cldr.default_backend!/0`)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.16.0 - Changelog","doc":"This is the changelog for Cldr v2.16.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-16-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)\n\n* Add `Cldr.Number.Formatter.Short.short_format_exponent/2` to support compact number pluralization that is added to CLDR 38 (for the \"fr\" locale only in this release)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.15.4 - Changelog","doc":"This is the changelog for Cldr v2.15.4 released on Septmber 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-15-4"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Use `Cldr.default_backend!/1` when available since `Cldr.default_backend/0` is deprecated as of `ex_cldr` version `2.18.0`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `Cldr.Decimal.compare/2` which works consistently with `Decimal` `1.x` and `2.x`\n\n* Apply compile-time detection of `Decimal` version in order to know the correct return type of `Decimal.parse/1` which differs between `1.x` and `2.x`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.15.3 - Changelog","doc":"This is the changelog for Cldr v2.15.3 released on September 5th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-15-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix documentation referencing `Cldr.known_locale_names/10` to correctly reference `Cldr.known_locale_names/0`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.15.2 - Changelog","doc":"This is the changelog for Cldr v2.15.2 released on August 30th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-15-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Removes dialyzer warning when running on Elixir 1.11.  Uses `Logger.warning/2` not `Logger.warn/2` in this case and uses an anonymous function not a string so that dialyzer is happy.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.15.1 - Changelog","doc":"This is the changelog for Cldr v2.15.1 released on June 23rd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-15-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes two number parsing bugs:\n\n  1. A bug whereby decimal and separator symbols would be impacted in non-number strings when using `MyApp.Cldr.Number.scan/2`\n  2. A bug whereby numbers using various localised symbols would not be recognised\n\n* Fix formatter pipeline generation which was including the `round nearest` pipeline stage even when not required.  Thanks to @jeroenvisser101 for the collaboration. Fixes #14.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.15.0 - Changelog","doc":"This is the changelog for Cldr v2.15.0 released on June 13th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-15-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support binary locale name as an argument to `Cldr.Number.System.number_system_from_locale/2`\n\n* Add `number_system_from_locale/1` to backend modules","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.14.0 - Changelog","doc":"This is the changelog for Cldr v2.14.0 released on May 27th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-14-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Number.Parser.parse/2` to parse numbers in a locale-aware manner\n\n* Add `Cldr.Number.Parser.scan/2` to parse a string into a list of string and numbers\n\n* Add `Cldr.Number.Parser.resolve_currencies/2` to match strings to currency codes in a list\n\n* Add `Cldr.Number.Parser.resolve_currency/2` to match a string to a currency code","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.13.2 - Changelog","doc":"This is the changelog for Cldr v2.13.2 released on May 16th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-13-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix regression and allow `:percent` formats in `Cldr.Number.to_string/3`. Thanks to @maennchen. Fixes #13.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.13.1 - Changelog","doc":"This is the changelog for Cldr v2.13.1 released on May 14th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-13-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix regression and allow `:fractional_digits` to be `0`. Thanks to @coladarci. Fixes #12.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.13.0 - Changelog","doc":"This is the changelog for Cldr v2.13.0 released on May 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-13-0"},{"type":"extras","title":"Breaking change - Changelog","doc":"* In previous releases, requesting a currency format in `Number.to_string/3` without specifying an option `:currency` would return an error. In this release, a currency is derived from the locale (either the `:locale` parameter or from `backend.get_locale()`). The affected currency formats are `:currency`, `:accounting`, `:currency_long` and `:currency_short`","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Enhancements - Changelog","doc":"* `Cldr.Number.to_string/2` now detects the number system from any supplied locale. If provided, the option `:number_system` takes precedence over the number system derived from a locale.\n\n* Add `:round_nearest` formatting option for `Cldr.Number.to_string/3`. If provided, this option overrides the value defined by the `:format` option.\n\n* Refines number system detection. The order of precedence is:\n\n\t* The `:number_system` option if provided\n\n\t* The `:number_system` from the locale if provided\n\n\t* The `:number_system` from the current locale for the supplied backend. This locale is retrieved with `backend.get_locale()`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.12.1 - Changelog","doc":"This is the changelog for Cldr v2.12.1 released on March 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-12-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use the RBNF format `spellout_numbering` instead of `spellout_cardinal` for the `Cldr.Number.to_string/3` option `format: :spellout` since `spellout_numbering` has a larger locale coverage of RBNF formats.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.12.0 - Changelog","doc":"This is the changelog for Cldr v2.12.0 released on January 21st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-12-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates version requirement for `cldr_utils` in order to support versions of `decimal` from `1.6` up to `2.0`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fixes an incorrect typespec on `Cldr.Number.Format.format_from_locale_or_options/1` that was causing a dialyzer warning","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.11.0 - Changelog","doc":"This is the changelog for Cldr v2.11.0 released on January 19th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-11-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Uses the number system defined by the locale if it is specified.  The number system is defined as part of the [U extension](https://unicode.org/reports/tr35/#u_Extension). The order of precedence is:\n\n  * :default if no option is provided to `MyApp.Cldr.Number.to_string/2` and no number system is defined in the locale\n\n  * The option `:number_system` if it is provided to `MyApp.Cldr.Number.to_string/2`\n\n  * The locale's `number_system` if it is defined and the option `:number_system` to `MyApp.Cldr.Number.to_string/2` is *not* provided\n\nExamples:\n```\n # Locale defines a number system and no option :number_system is provided\n iex> TestBackend.Cldr.Number.to_string(1234, locale: \"th-u-nu-thai\")\n {:ok, \"๑,๒๓๔\"}\n\n # Locale defines a number system but an option :number_system is also provided which\n # take precedence\n iex> MyApp.Cldr.Number.to_string 1234, locale: \"th-u-nu-latn\", number_system: :thai\n {:ok, \"๑,๒๓๔\"}\n\n # A number system is defined in the locale but it is not supported by the\n # locale\n iex> MyApp.Cldr.Number.to_string 1234, locale: \"en-AU-u-nu-thai\"\n {:error,\n  {Cldr.UnknownNumberSystemError,\n   \"The number system :thai is unknown for the locale named \\\"en\\\". Valid number systems are %{default: :latn, native: :latn}\"}}\n```\n\n* Uses the currency code defined by the locale if it is specified and the number format requested is `:currency`. The currency code is defined as part of the [U extension](https://unicode.org/reports/tr35/#u_Extension). The order of precedence is:\n\n  * The option `:currency` if it is provided to `MyApp.Cldr.Number.to_string/2`\n\n  * The locale's `currency code` if it is defined and the option `:currency` to `MyApp.Cldr.Number.to_string/2` is *not* provided\n\nExamples:\n```\n # Use the currency code :AUD specified in the locale\n iex> MyApp.Cldr.Number.to_string 1234, locale: \"en-AU-u-cu-aud\", format: :currency\n {:ok, \"A$1,234.00\"}\n\n # Use the currency code :USD provided as an option in precedence over the currency code\n # defined by the locale\n iex> MyApp.Cldr.Number.to_string 1234, locale: \"en-AU-u-cu-aud\", format: :currency, currency: :USD\n {:ok, \"$1,234.00\"}\n```\n\n* Uses the currency format defined by the locale if it is specified and the number format requested is `:currency` or `:accounting`. The currency format is defined as part of the [U extension](https://unicode.org/reports/tr35/#u_Extension). The order of precedence is:\n\n  * The locale's `currency format` if it is defined and the option `:format` to `MyApp.Cldr.Number.to_string/2` is either `:currency` or `:accounting`. Therefore the locales currency format takes precedence over the `:format` argument but only if `:format` is a currency format.\n\n  * The option `:format` in every other case\n\nExamples:\n```\n # Using in the locale currency format - just happens to be the same as the format option\n iex> MyApp.Cldr.Number.to_string -1234, locale: \"en-AU-u-cu-aud-cf-standard\", format: :currency\n {:ok, \"A$-1,234.00\"}\n\n # The locale format takes precedence over the format option\n iex> MyApp.Cldr.Number.to_string -1234, locale: \"en-AU-u-cu-aud-cf-standard\", format: :accounting\n {:ok, \"A$-1,234.00\"}\n\n iex> MyApp.Cldr.Number.to_string -1234, locale: \"en-AU-u-cu-aud-cf-account\", format: :accounting\n {:ok, \"(A$1,234.00)\"}\n\n iex> MyApp.Cldr.Number.to_string -1234, locale: \"en-AU-u-cu-aud-cf-account\", format: :currency\n {:ok, \"(A$1,234.00)\"}\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.10.0 - Changelog","doc":"This is the changelog for Cldr v2.10.0 released on January 15th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-10-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes formatting of negative percentages. Actually fixes an issue where the default negative format would be incorrect in many cases. Thanks to @maennchen. Closes #11.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Optionally logs a warning if compiling a number format at runtime. The warning is emitted only once for each format to reduce log clutter. The log warning is emitted if the backend configuration key `:supress_warnings` is set to `false` (this is the default value). The `warn_once` mechanism depends on the availability of the `:persistent_term` module which is only available from OTP 21.2 onwards. On earlier releases of OTP no warning will be emitted.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.9.0 - Changelog","doc":"This is the changelog for Cldr v2.9.0 released on October 20th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-9-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds option `:currency_symbol` to `Cldr.Number.to_string/2`. This option, when set to `:iso` changes a currency format to force using the ISO currency code instead of the native currency symbol.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.8.0 - Changelog","doc":"This is the changelog for Cldr v2.8.0 released on October 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update [ex_cldr](https://github.com/elixir-cldr/cldr) to version `2.11.0` which encapsulates [CLDR](https://cldr.unicode.org) version `36.0.0` data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.7.2 - Changelog","doc":"This is the changelog for Cldr v2.7.2 released on September 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-7-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Call `Keyword.get_lazy/3` when accessing `Cldr.default_locale/0` to avoid exceptions when no default backend is configured but an optional `:backend` has been passed.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.7.1 - Changelog","doc":"This is the changelog for Cldr v2.7.1 released on August 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-7-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `@spec` for `Cldr.Number.to_string/3` and `Cldr.Number.to_string!/3`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.7.0 - Changelog","doc":"This is the changelog for Cldr v2.7.0 released on August 21st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* An option `:backend` can be passed to `Cldr.Number.to_string/3` and it will be used if being called as `Cldr.Number.to_string/2`.  This means that for a call like `Cldr.Number.to_string(number, backend, options)` which has an option `:backend`, the call can be replaced with `Cldr.Number.to_string(number, options)`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.6.4 - Changelog","doc":"This is the changelog for Cldr v2.6.4 released on June 16th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-6-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix the default value for the `backend` parameter for `Cldr.Number.to_string/3`\n\n* Allow `Cldr.Number.to_string/3` to be called as `Cldr.Number.to_string  ,  ` as long as there is a default backend configured in `config.exs`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.6.3 - Changelog","doc":"This is the changelog for Cldr v2.6.3 released on June 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-6-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correctly interpret the special short format `0` to mean \"format as a normal decimal or currency number\". Thanks to @epilgrim.  Closes #10","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.6.2 - Changelog","doc":"This is the changelog for Cldr v2.6.2 released on June 12th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-6-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Don't transliterate in `Cldr.Number.Transliterate.transliterate_digits/3` if `from` and `to` number systems are the same.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.6.1 - Changelog","doc":"This is the changelog for Cldr v2.6.1 released on June 2nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-6-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Ensure `Cldr.Number.to_string/3` doesn't transliterate is the number systems are compatible for a given locale.  Basically, if the local and number system don't require transliteration from `0..9` to another script (like indian, arabic, ...) then we don't do it.  This improves performance by about 10% for this common case.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.6.0 - Changelog","doc":"This is the changelog for Cldr v2.6.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 35.0.0](http://cldr.unicode.org/index/downloads/cldr-35) released on March 27th 2019.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.5.0 - Changelog","doc":"This is the changelog for Cldr v2.5.0 released on March 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Supports `Cldr.default_backend()` as a default for a backend on functions in `Cldr.Number`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.4.4 - Changelog","doc":"This is the changelog for Cldr v2.4.4 released on March 21st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-4-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Rbnf.Ordinal and Rbnf.Spellout now respect the optional generation of @moduledocs in a backend","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.4.3 - Changelog","doc":"This is the changelog for Cldr v2.4.3 released on March 20th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-4-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.4.2 - Changelog","doc":"This is the changelog for Cldr v2.4.2 released on March 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-4-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Makes generation of documentation for backend modules optional.  This is implemented by the `:generate_docs` option to the backend configuration.  The default is `true`. For example:\n\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    default_locale: \"en-001\",\n    locales: [\"en\", \"ja\"],\n    gettext: MyApp.Gettext,\n    generate_docs: false\nend\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.4.1 - Changelog","doc":"This is the changelog for Cldr v2.4.1 released on March 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-4-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix fractional grouping. Previously when there was no grouping, the group size was being set to the number of fractional digits.\n\n* Fix scientific precision. Previously the mantissa was not being rounded because the prioritisation of significant digits over exponent digits was not being correctly reconciled.\n\n* Fix formatting precision of an exponent. A format of `0E00` will now format the exponent with two digits.\n\n* Fix o silence dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.4.0 - Changelog","doc":"This is the changelog for Cldr v2.4.0 released on March 4th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Number.Format.default_grouping_for/2` to return the default grouping of digits for a locale. This is useful for external number formats like [ex_cldr_print](https://github.com/kipcole9/cldr_print).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.3.0 - Changelog","doc":"This is the changelog for Cldr v2.3.0 released on March 1st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Opens up the formatting pipeline for use by other formatting systems like `printf`. This is implemented by the introduction of `Cldr.Number.Format.Meta` to create the abstract metadata struct.  This struct is used for `Cldr.Number.to_string/3` and is now available for use by other libraries. The function `Cldr.Number.Formatter.Decimal.to_string/3` is the primary function that should be used by other libraries.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.2.0 - Changelog","doc":"This is the changelog for Cldr v2.2.0 released on Febriuary 24th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-2-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix generating an error tuple when the number system is a binary\n\n* Fix `@doc` errors","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Number.Symbol.all_decimal_symbols/1` and `Cldr.Number.Symbol.all_grouping_symbols/1` that support parsing of numbers.  The symbols are returned as a list.\n\n* Adds `Cldr.Number.Symbol.all_decimal_symbols_class/1` and `Cldr.Number.Symbol.all_grouping_symbols_class/1`. The symbols are returned as a `String.t` which can then be used to define a character class when building a regex.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.1.1 - Changelog","doc":"This is the changelog for Cldr v2.1.1 released on February 3rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-1-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Formats `Decimal.new(\"-0\")` the same as `Decimal.new(\"0\")` which is to say without the sign.  Although the [Decimal standard](http://speleotrove.com/decimal/damisc.html#refcotot) upon which the [Decimal](https://github.com/ericmj/decimal) library is based allows for `-0`, formatting this as a string with the sign is not consistent with the output for integers and floats.  Consistency is, in this case, considered to be the correct approach.\n\n* Fix documentation errors","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Numbers v2.1.0 - Changelog","doc":"This is the changelog for Cldr v2.1.0 released on December 1st, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added `Cldr.Number.to_at_least_string/3`, `Cldr.Number.to_at_most_string/3`, `Cldr.Number.to_range_string/3` and `Cldr.Number.to_approx_string/3` to format numbers in way that conveys the relevant intent. These functions are also defined one each backend. For example, in the `\"en\"` locale:\n\n```\niex> MyApp.Cldr.Number.to_at_least_string 1234\n{:ok, \"1,234+\"}\n\niex> MyApp.Cldr.Number.to_at_most_string 1234\n{:ok, \"≤1,234\"}\n\niex> MyApp.Cldr.Number.to_approx_string 1234\n{:ok, \"~1,234\"}\n\niex> MyApp.Cldr.Number.to_range_string 1234..5678\n{:ok, \"1,234–5,678\"}\n```\n\n* Refactored options for `Cldr.Numbers.to_string/3` and other functions that use the common number formatting options structure.  Options are now parsed and contained in a `Cldr.Number.Format.Options` struct. A user-visible benefit is that if passing a `Cldr.Number.Format.Options` struct to `Cldr.Number.to_string/3` then no further validation or normalization will be performed.  Therefore if you are formatting in a tight loop and using common options, saving the options in advance will yield some performance improvement.  A `Cldr.Number.Format.Options` struct can be returned by called `Cldr.Number.Format.Options.validate_options(backend, options)`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Numbers v2.0.0 - Changelog","doc":"This is the changelog for Cldr v2.0.0 released on November 22nd, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_numbers/tags)","ref":"changelog.html#cldr_numbers-v2-0-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* `ex_cldr_numbers` now depends upon [ex_cldr version 2.0](https://hex.pm/packages/ex_cldr/2.0.0).  As a result it is a requirement that at least one backend module be configured as described in the [ex_cldr readme](https://hexdocs.pm/ex_cldr/2.0.0/readme.html#configuration).\n\n* The public API is now based upon functions defined on a backend module. Therefore calls to functions such as `Cldr.Number.to_string/2` should be replaced with calls to `MyApp.Cldr.Number.to_string/2` (assuming your configured backend module is called `MyApp.Cldr`).","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Number.validate_number_system/3` and ` .Number.validate_number_system/2` that are now the canonical way to validate and return a number system from either a number system binary or atom, or from a number system name.\n\n* `Cldr.Number.{Ordinal, Cardinal}.pluralize/3` now support ranges, not just numbers\n\n* Currency spacing is now applied for currency formatting.  Depending on the locale, some text may be placed between the current symbol and the number.  This enhanced readability, it does not change the number formatting itself.  For example you can see below that for the locale \"en\", when the currency symbol is text, a non-breaking space is introduced between it and the number.\n\n```\niex> MyApp.Cldr.Number.to_string 2345, currency: :USD, format: \"¤#,##0.00\"\n{:ok, \"$2,345.00\"}\n\niex> MyApp.Cldr.Number.to_string 2345, currency: :USD, format: \"¤¤#,##0.00\"\n{:ok, \"USD 2,345.00\"}\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2017-2023 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}